# This file is auto-generated by AWSMetadata.jl
using AWS
using AWS.AWSServices: codeartifact

using AWS.Compat
using AWS.UUIDs
"""
    AssociateExternalConnection()

Adds an existing external connection to a repository. One external connection is allowed per repository.  A repository can have one or more upstream repositories, or an external connection. 

# Required Parameters
- `domain`: The name of the domain that contains the repository.
- `external-connection`:  The name of the external connection to add to the repository. The following values are supported:     public:npmjs - for the npm public repository.     public:pypi - for the Python Package Index.     public:maven-central - for Maven Central.     public:maven-googleandroid - for the Google Android repository.     public:maven-gradleplugins - for the Gradle plugins repository.     public:maven-commonsware - for the CommonsWare Android repository.   
- `repository`:  The name of the repository to which the external connection is added. 

# Optional Parameters
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
"""

associate_external_connection(domain, external_connection, repository; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/repository/external-connection", Dict{String, Any}("domain"=>domain, "external-connection"=>external_connection, "repository"=>repository); aws_config=aws_config)
associate_external_connection(domain, external_connection, repository, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/repository/external-connection", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain, "external-connection"=>external_connection, "repository"=>repository), args)); aws_config=aws_config)

"""
    CopyPackageVersions()

 Copies package versions from one repository to another repository in the same domain.    You must specify versions or versionRevisions. You cannot specify both.  

# Required Parameters
- `destination-repository`:  The name of the repository into which package versions are copied. 
- `domain`:  The name of the domain that contains the source and destination repositories. 
- `format`:  The format of the package that is copied. The valid package types are:     npm: A Node Package Manager (npm) package.     pypi: A Python Package Index (PyPI) package.     maven: A Maven package that contains compiled code in a distributable format, such as a JAR file.   
- `package`:  The name of the package that is copied. 
- `source-repository`:  The name of the repository that contains the package versions to copy. 

# Optional Parameters
- `allowOverwrite`:  Set to true to overwrite a package version that already exists in the destination repository. If set to false and the package version already exists in the destination repository, the package version is returned in the failedVersions field of the response with an ALREADY_EXISTS error code. 
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
- `includeFromUpstream`:  Set to true to copy packages from repositories that are upstream from the source repository to the destination repository. The default setting is false. For more information, see Working with upstream repositories. 
- `namespace`:  The namespace of the package. The package component that specifies its namespace depends on its type. For example:     The namespace of a Maven package is its groupId.     The namespace of an npm package is its scope.     A Python package does not contain a corresponding component, so Python packages do not have a namespace.   
- `versionRevisions`:  A list of key-value pairs. The keys are package versions and the values are package version revisions. A CopyPackageVersion operation succeeds if the specified versions in the source repository match the specified package version revision.    You must specify versions or versionRevisions. You cannot specify both.  
- `versions`:  The versions of the package to copy.    You must specify versions or versionRevisions. You cannot specify both.  
"""

copy_package_versions(destination_repository, domain, format, package, source_repository; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/package/versions/copy", Dict{String, Any}("destination-repository"=>destination_repository, "domain"=>domain, "format"=>format, "package"=>package, "source-repository"=>source_repository); aws_config=aws_config)
copy_package_versions(destination_repository, domain, format, package, source_repository, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/package/versions/copy", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("destination-repository"=>destination_repository, "domain"=>domain, "format"=>format, "package"=>package, "source-repository"=>source_repository), args)); aws_config=aws_config)

"""
    CreateDomain()

 Creates a domain. CodeArtifact domains make it easier to manage multiple repositories across an organization. You can use a domain to apply permissions across many repositories owned by different AWS accounts. An asset is stored only once in a domain, even if it's in multiple repositories.  Although you can have multiple domains, we recommend a single production domain that contains all published artifacts so that your development teams can find and share packages. You can use a second pre-production domain to test changes to the production domain configuration. 

# Required Parameters
- `domain`:  The name of the domain to create. All domain names in an AWS Region that are in the same AWS account must be unique. The domain name is used as the prefix in DNS hostnames. Do not use sensitive information in a domain name because it is publicly discoverable. 

# Optional Parameters
- `encryptionKey`:  The encryption key for the domain. This is used to encrypt content stored in a domain. An encryption key can be a key ID, a key Amazon Resource Name (ARN), a key alias, or a key alias ARN. To specify an encryptionKey, your IAM role must have kms:DescribeKey and kms:CreateGrant permissions on the encryption key that is used. For more information, see DescribeKey in the AWS Key Management Service API Reference and AWS KMS API Permissions Reference in the AWS Key Management Service Developer Guide.    CodeArtifact supports only symmetric CMKs. Do not associate an asymmetric CMK with your domain. For more information, see Using symmetric and asymmetric keys in the AWS Key Management Service Developer Guide.  
"""

create_domain(domain; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/domain", Dict{String, Any}("domain"=>domain); aws_config=aws_config)
create_domain(domain, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/domain", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain), args)); aws_config=aws_config)

"""
    CreateRepository()

 Creates a repository. 

# Required Parameters
- `domain`:  The domain that contains the created repository. 
- `repository`:  The name of the repository to create. 

# Optional Parameters
- `description`:  A description of the created repository. 
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
- `upstreams`:  A list of upstream repositories to associate with the repository. The order of the upstream repositories in the list determines their priority order when AWS CodeArtifact looks for a requested package version. For more information, see Working with upstream repositories. 
"""

create_repository(domain, repository; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/repository", Dict{String, Any}("domain"=>domain, "repository"=>repository); aws_config=aws_config)
create_repository(domain, repository, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/repository", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain, "repository"=>repository), args)); aws_config=aws_config)

"""
    DeleteDomain()

 Deletes a domain. You cannot delete a domain that contains repositories. If you want to delete a domain with repositories, first delete its repositories. 

# Required Parameters
- `domain`:  The name of the domain to delete. 

# Optional Parameters
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
"""

delete_domain(domain; aws_config::AWSConfig=global_aws_config()) = codeartifact("DELETE", "/v1/domain", Dict{String, Any}("domain"=>domain); aws_config=aws_config)
delete_domain(domain, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("DELETE", "/v1/domain", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain), args)); aws_config=aws_config)

"""
    DeleteDomainPermissionsPolicy()

 Deletes the resource policy set on a domain. 

# Required Parameters
- `domain`:  The name of the domain associated with the resource policy to be deleted. 

# Optional Parameters
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
- `policy-revision`:  The current revision of the resource policy to be deleted. This revision is used for optimistic locking, which prevents others from overwriting your changes to the domain's resource policy. 
"""

delete_domain_permissions_policy(domain; aws_config::AWSConfig=global_aws_config()) = codeartifact("DELETE", "/v1/domain/permissions/policy", Dict{String, Any}("domain"=>domain); aws_config=aws_config)
delete_domain_permissions_policy(domain, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("DELETE", "/v1/domain/permissions/policy", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain), args)); aws_config=aws_config)

"""
    DeletePackageVersions()

 Deletes one or more versions of a package. A deleted package version cannot be restored in your repository. If you want to remove a package version from your repository and be able to restore it later, set its status to Archived. Archived packages cannot be downloaded from a repository and don't show up with list package APIs (for example,  ListackageVersions ), but you can restore them using  UpdatePackageVersionsStatus . 

# Required Parameters
- `domain`:  The name of the domain that contains the package to delete. 
- `format`:  The format of the package versions to delete. The valid values are:     npm     pypi     maven   
- `package`:  The name of the package with the versions to delete. 
- `repository`:  The name of the repository that contains the package versions to delete. 
- `versions`:  An array of strings that specify the versions of the package to delete. 

# Optional Parameters
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
- `expectedStatus`:  The expected status of the package version to delete. Valid values are:     Published     Unfinished     Unlisted     Archived     Disposed   
- `namespace`:  The namespace of the package. The package component that specifies its namespace depends on its type. For example:     The namespace of a Maven package is its groupId.     The namespace of an npm package is its scope.     A Python package does not contain a corresponding component, so Python packages do not have a namespace.   
"""

delete_package_versions(domain, format, package, repository, versions; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/package/versions/delete", Dict{String, Any}("domain"=>domain, "format"=>format, "package"=>package, "repository"=>repository, "versions"=>versions); aws_config=aws_config)
delete_package_versions(domain, format, package, repository, versions, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/package/versions/delete", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain, "format"=>format, "package"=>package, "repository"=>repository, "versions"=>versions), args)); aws_config=aws_config)

"""
    DeleteRepository()

 Deletes a repository. 

# Required Parameters
- `domain`:  The name of the domain that contains the repository to delete. 
- `repository`:  The name of the repository to delete. 

# Optional Parameters
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
"""

delete_repository(domain, repository; aws_config::AWSConfig=global_aws_config()) = codeartifact("DELETE", "/v1/repository", Dict{String, Any}("domain"=>domain, "repository"=>repository); aws_config=aws_config)
delete_repository(domain, repository, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("DELETE", "/v1/repository", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain, "repository"=>repository), args)); aws_config=aws_config)

"""
    DeleteRepositoryPermissionsPolicy()

 Deletes the resource policy that is set on a repository. After a resource policy is deleted, the permissions allowed and denied by the deleted policy are removed. The effect of deleting a resource policy might not be immediate.    Use DeleteRepositoryPermissionsPolicy with caution. After a policy is deleted, AWS users, roles, and accounts lose permissions to perform the repository actions granted by the deleted policy.  

# Required Parameters
- `domain`:  The name of the domain that contains the repository associated with the resource policy to be deleted. 
- `repository`:  The name of the repository that is associated with the resource policy to be deleted 

# Optional Parameters
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
- `policy-revision`:  The revision of the repository's resource policy to be deleted. This revision is used for optimistic locking, which prevents others from accidentally overwriting your changes to the repository's resource policy. 
"""

delete_repository_permissions_policy(domain, repository; aws_config::AWSConfig=global_aws_config()) = codeartifact("DELETE", "/v1/repository/permissions/policies", Dict{String, Any}("domain"=>domain, "repository"=>repository); aws_config=aws_config)
delete_repository_permissions_policy(domain, repository, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("DELETE", "/v1/repository/permissions/policies", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain, "repository"=>repository), args)); aws_config=aws_config)

"""
    DescribeDomain()

 Returns a  DomainDescription  object that contains information about the requested domain. 

# Required Parameters
- `domain`:  A string that specifies the name of the requested domain. 

# Optional Parameters
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
"""

describe_domain(domain; aws_config::AWSConfig=global_aws_config()) = codeartifact("GET", "/v1/domain", Dict{String, Any}("domain"=>domain); aws_config=aws_config)
describe_domain(domain, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("GET", "/v1/domain", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain), args)); aws_config=aws_config)

"""
    DescribePackageVersion()

 Returns a  PackageVersionDescription  object that contains information about the requested package version. 

# Required Parameters
- `domain`:  The name of the domain that contains the repository that contains the package version. 
- `format`:  A format that specifies the type of the requested package version. The valid values are:     npm     pypi     maven   
- `package`:  The name of the requested package version. 
- `repository`:  The name of the repository that contains the package version. 
- `version`:  A string that contains the package version (for example, 3.5.2). 

# Optional Parameters
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
- `namespace`:  The namespace of the package. The package component that specifies its namespace depends on its type. For example:     The namespace of a Maven package is its groupId.     The namespace of an npm package is its scope.     A Python package does not contain a corresponding component, so Python packages do not have a namespace.   
"""

describe_package_version(domain, format, package, repository, version; aws_config::AWSConfig=global_aws_config()) = codeartifact("GET", "/v1/package/version", Dict{String, Any}("domain"=>domain, "format"=>format, "package"=>package, "repository"=>repository, "version"=>version); aws_config=aws_config)
describe_package_version(domain, format, package, repository, version, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("GET", "/v1/package/version", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain, "format"=>format, "package"=>package, "repository"=>repository, "version"=>version), args)); aws_config=aws_config)

"""
    DescribeRepository()

 Returns a RepositoryDescription object that contains detailed information about the requested repository. 

# Required Parameters
- `domain`:  The name of the domain that contains the repository to describe. 
- `repository`:  A string that specifies the name of the requested repository. 

# Optional Parameters
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
"""

describe_repository(domain, repository; aws_config::AWSConfig=global_aws_config()) = codeartifact("GET", "/v1/repository", Dict{String, Any}("domain"=>domain, "repository"=>repository); aws_config=aws_config)
describe_repository(domain, repository, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("GET", "/v1/repository", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain, "repository"=>repository), args)); aws_config=aws_config)

"""
    DisassociateExternalConnection()

 Removes an existing external connection from a repository. 

# Required Parameters
- `domain`: The name of the domain that contains the repository from which to remove the external repository. 
- `external-connection`: The name of the external connection to be removed from the repository. 
- `repository`: The name of the repository from which the external connection will be removed. 

# Optional Parameters
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
"""

disassociate_external_connection(domain, external_connection, repository; aws_config::AWSConfig=global_aws_config()) = codeartifact("DELETE", "/v1/repository/external-connection", Dict{String, Any}("domain"=>domain, "external-connection"=>external_connection, "repository"=>repository); aws_config=aws_config)
disassociate_external_connection(domain, external_connection, repository, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("DELETE", "/v1/repository/external-connection", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain, "external-connection"=>external_connection, "repository"=>repository), args)); aws_config=aws_config)

"""
    DisposePackageVersions()

 Deletes the assets in package versions and sets the package versions' status to Disposed. A disposed package version cannot be restored in your repository because its assets are deleted.   To view all disposed package versions in a repository, use  ListackageVersions  and set the  status  parameter to Disposed.   To view information about a disposed package version, use  ListPackageVersions  and set the  status  parameter to Disposed. 

# Required Parameters
- `domain`:  The name of the domain that contains the repository you want to dispose. 
- `format`:  A format that specifies the type of package versions you want to dispose. The valid values are:     npm     pypi     maven   
- `package`:  The name of the package with the versions you want to dispose. 
- `repository`:  The name of the repository that contains the package versions you want to dispose. 
- `versions`:  The versions of the package you want to dispose. 

# Optional Parameters
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
- `expectedStatus`:  The expected status of the package version to dispose. Valid values are:     Published     Unfinished     Unlisted     Archived     Disposed   
- `namespace`:  The namespace of the package. The package component that specifies its namespace depends on its type. For example:     The namespace of a Maven package is its groupId.     The namespace of an npm package is its scope.     A Python package does not contain a corresponding component, so Python packages do not have a namespace.   
- `versionRevisions`:  The revisions of the package versions you want to dispose. 
"""

dispose_package_versions(domain, format, package, repository, versions; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/package/versions/dispose", Dict{String, Any}("domain"=>domain, "format"=>format, "package"=>package, "repository"=>repository, "versions"=>versions); aws_config=aws_config)
dispose_package_versions(domain, format, package, repository, versions, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/package/versions/dispose", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain, "format"=>format, "package"=>package, "repository"=>repository, "versions"=>versions), args)); aws_config=aws_config)

"""
    GetAuthorizationToken()

 Generates a temporary authentication token for accessing repositories in the domain. This API requires the codeartifact:GetAuthorizationToken and sts:GetServiceBearerToken permissions.   CodeArtifact authorization tokens are valid for a period of 12 hours when created with the login command. You can call login periodically to refresh the token. When you create an authorization token with the GetAuthorizationToken API, you can set a custom authorization period, up to a maximum of 12 hours, with the durationSeconds parameter. The authorization period begins after login or GetAuthorizationToken is called. If login or GetAuthorizationToken is called while assuming a role, the token lifetime is independent of the maximum session duration of the role. For example, if you call sts assume-role and specify a session duration of 15 minutes, then generate a CodeArtifact authorization token, the token will be valid for the full authorization period even though this is longer than the 15-minute session duration. See Using IAM Roles for more information on controlling session duration.  

# Required Parameters
- `domain`:  The name of the domain that is in scope for the generated authorization token. 

# Optional Parameters
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
- `duration`: The time, in seconds, that the generated authorization token is valid.
"""

get_authorization_token(domain; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/authorization-token", Dict{String, Any}("domain"=>domain); aws_config=aws_config)
get_authorization_token(domain, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/authorization-token", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain), args)); aws_config=aws_config)

"""
    GetDomainPermissionsPolicy()

 Returns the resource policy attached to the specified domain.    The policy is a resource-based policy, not an identity-based policy. For more information, see Identity-based policies and resource-based policies  in the AWS Identity and Access Management User Guide.  

# Required Parameters
- `domain`:  The name of the domain to which the resource policy is attached. 

# Optional Parameters
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
"""

get_domain_permissions_policy(domain; aws_config::AWSConfig=global_aws_config()) = codeartifact("GET", "/v1/domain/permissions/policy", Dict{String, Any}("domain"=>domain); aws_config=aws_config)
get_domain_permissions_policy(domain, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("GET", "/v1/domain/permissions/policy", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain), args)); aws_config=aws_config)

"""
    GetPackageVersionAsset()

 Returns an asset (or file) that is in a package. For example, for a Maven package version, use GetPackageVersionAsset to download a JAR file, a POM file, or any other assets in the package version. 

# Required Parameters
- `asset`:  The name of the requested asset. 
- `domain`:  The domain that contains the repository that contains the package version with the requested asset. 
- `format`:  A format that specifies the type of the package version with the requested asset file. The valid values are:     npm     pypi     maven   
- `package`:  The name of the package that contains the requested asset. 
- `repository`:  The repository that contains the package version with the requested asset. 
- `version`:  A string that contains the package version (for example, 3.5.2). 

# Optional Parameters
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
- `namespace`:  The namespace of the package. The package component that specifies its namespace depends on its type. For example:     The namespace of a Maven package is its groupId.     The namespace of an npm package is its scope.     A Python package does not contain a corresponding component, so Python packages do not have a namespace.   
- `revision`:  The name of the package version revision that contains the requested asset. 
"""

get_package_version_asset(asset, domain, format, package, repository, version; aws_config::AWSConfig=global_aws_config()) = codeartifact("GET", "/v1/package/version/asset", Dict{String, Any}("asset"=>asset, "domain"=>domain, "format"=>format, "package"=>package, "repository"=>repository, "version"=>version); aws_config=aws_config)
get_package_version_asset(asset, domain, format, package, repository, version, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("GET", "/v1/package/version/asset", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("asset"=>asset, "domain"=>domain, "format"=>format, "package"=>package, "repository"=>repository, "version"=>version), args)); aws_config=aws_config)

"""
    GetPackageVersionReadme()

 Gets the readme file or descriptive text for a package version. For packages that do not contain a readme file, CodeArtifact extracts a description from a metadata file. For example, from the &lt;description&gt; element in the pom.xml file of a Maven package.   The returned text might contain formatting. For example, it might contain formatting for Markdown or reStructuredText. 

# Required Parameters
- `domain`:  The name of the domain that contains the repository that contains the package version with the requested readme file. 
- `format`:  A format that specifies the type of the package version with the requested readme file. The valid values are:     npm     pypi     maven   
- `package`:  The name of the package version that contains the requested readme file. 
- `repository`:  The repository that contains the package with the requested readme file. 
- `version`:  A string that contains the package version (for example, 3.5.2). 

# Optional Parameters
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
- `namespace`:  The namespace of the package. The package component that specifies its namespace depends on its type. For example:     The namespace of a Maven package is its groupId.     The namespace of an npm package is its scope.     A Python package does not contain a corresponding component, so Python packages do not have a namespace.   
"""

get_package_version_readme(domain, format, package, repository, version; aws_config::AWSConfig=global_aws_config()) = codeartifact("GET", "/v1/package/version/readme", Dict{String, Any}("domain"=>domain, "format"=>format, "package"=>package, "repository"=>repository, "version"=>version); aws_config=aws_config)
get_package_version_readme(domain, format, package, repository, version, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("GET", "/v1/package/version/readme", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain, "format"=>format, "package"=>package, "repository"=>repository, "version"=>version), args)); aws_config=aws_config)

"""
    GetRepositoryEndpoint()

 Returns the endpoint of a repository for a specific package format. A repository has one endpoint for each package format:     npm     pypi     maven   

# Required Parameters
- `domain`:  The name of the domain that contains the repository. 
- `format`:  Returns which endpoint of a repository to return. A repository has one endpoint for each package format:     npm     pypi     maven   
- `repository`:  The name of the repository. 

# Optional Parameters
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain that contains the repository. It does not include dashes or spaces. 
"""

get_repository_endpoint(domain, format, repository; aws_config::AWSConfig=global_aws_config()) = codeartifact("GET", "/v1/repository/endpoint", Dict{String, Any}("domain"=>domain, "format"=>format, "repository"=>repository); aws_config=aws_config)
get_repository_endpoint(domain, format, repository, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("GET", "/v1/repository/endpoint", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain, "format"=>format, "repository"=>repository), args)); aws_config=aws_config)

"""
    GetRepositoryPermissionsPolicy()

 Returns the resource policy that is set on a repository. 

# Required Parameters
- `domain`:  The name of the domain containing the repository whose associated resource policy is to be retrieved. 
- `repository`:  The name of the repository whose associated resource policy is to be retrieved. 

# Optional Parameters
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
"""

get_repository_permissions_policy(domain, repository; aws_config::AWSConfig=global_aws_config()) = codeartifact("GET", "/v1/repository/permissions/policy", Dict{String, Any}("domain"=>domain, "repository"=>repository); aws_config=aws_config)
get_repository_permissions_policy(domain, repository, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("GET", "/v1/repository/permissions/policy", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain, "repository"=>repository), args)); aws_config=aws_config)

"""
    ListDomains()

 Returns a list of  DomainSummary  objects for all domains owned by the AWS account that makes this call. Each returned DomainSummary object contains information about a domain. 

# Optional Parameters
- `maxResults`:  The maximum number of results to return per page. 
- `nextToken`:  The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. 
"""

list_domains(; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/domains"; aws_config=aws_config)
list_domains(args::AbstractDict{String, Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/domains", args; aws_config=aws_config)

"""
    ListPackageVersionAssets()

 Returns a list of  AssetSummary  objects for assets in a package version. 

# Required Parameters
- `domain`:  The name of the domain that contains the repository associated with the package version assets. 
- `format`:  The format of the package that contains the returned package version assets. The valid package types are:     npm: A Node Package Manager (npm) package.     pypi: A Python Package Index (PyPI) package.     maven: A Maven package that contains compiled code in a distributable format, such as a JAR file.   
- `package`:  The name of the package that contains the returned package version assets. 
- `repository`:  The name of the repository that contains the package that contains the returned package version assets. 
- `version`:  A string that contains the package version (for example, 3.5.2). 

# Optional Parameters
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
- `max-results`:  The maximum number of results to return per page. 
- `namespace`:  The namespace of the package. The package component that specifies its namespace depends on its type. For example:     The namespace of a Maven package is its groupId.     The namespace of an npm package is its scope.     A Python package does not contain a corresponding component, so Python packages do not have a namespace.   
- `next-token`:  The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. 
"""

list_package_version_assets(domain, format, package, repository, version; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/package/version/assets", Dict{String, Any}("domain"=>domain, "format"=>format, "package"=>package, "repository"=>repository, "version"=>version); aws_config=aws_config)
list_package_version_assets(domain, format, package, repository, version, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/package/version/assets", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain, "format"=>format, "package"=>package, "repository"=>repository, "version"=>version), args)); aws_config=aws_config)

"""
    ListPackageVersionDependencies()

 Returns the direct dependencies for a package version. The dependencies are returned as  PackageDependency  objects. CodeArtifact extracts the dependencies for a package version from the metadata file for the package format (for example, the package.json file for npm packages and the pom.xml file for Maven). Any package version dependencies that are not listed in the configuration file are not returned. 

# Required Parameters
- `domain`:  The domain that contains the repository that contains the requested package version dependencies. 
- `format`:  The format of the package with the requested dependencies. The valid package types are:     npm: A Node Package Manager (npm) package.     pypi: A Python Package Index (PyPI) package.     maven: A Maven package that contains compiled code in a distributable format, such as a JAR file.   
- `package`:  The name of the package versions' package. 
- `repository`:  The name of the repository that contains the requested package version. 
- `version`:  A string that contains the package version (for example, 3.5.2). 

# Optional Parameters
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
- `namespace`:  The namespace of the package. The package component that specifies its namespace depends on its type. For example:     The namespace of a Maven package is its groupId.     The namespace of an npm package is its scope.     A Python package does not contain a corresponding component, so Python packages do not have a namespace.   
- `next-token`:  The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. 
"""

list_package_version_dependencies(domain, format, package, repository, version; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/package/version/dependencies", Dict{String, Any}("domain"=>domain, "format"=>format, "package"=>package, "repository"=>repository, "version"=>version); aws_config=aws_config)
list_package_version_dependencies(domain, format, package, repository, version, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/package/version/dependencies", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain, "format"=>format, "package"=>package, "repository"=>repository, "version"=>version), args)); aws_config=aws_config)

"""
    ListPackageVersions()

 Returns a list of  PackageVersionSummary  objects for package versions in a repository that match the request parameters. 

# Required Parameters
- `domain`:  The name of the domain that contains the repository that contains the returned package versions. 
- `format`:  The format of the returned packages. The valid package types are:     npm: A Node Package Manager (npm) package.     pypi: A Python Package Index (PyPI) package.     maven: A Maven package that contains compiled code in a distributable format, such as a JAR file.   
- `package`:  The name of the package for which you want to return a list of package versions. 
- `repository`:  The name of the repository that contains the package. 

# Optional Parameters
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
- `max-results`:  The maximum number of results to return per page. 
- `namespace`:  The namespace of the package. The package component that specifies its namespace depends on its type. For example:     The namespace of a Maven package is its groupId.     The namespace of an npm package is its scope.     A Python package does not contain a corresponding component, so Python packages do not have a namespace.   
- `next-token`:  The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. 
- `sortBy`:  How to sort the returned list of package versions. 
- `status`:  A string that specifies the status of the package versions to include in the returned list. It can be one of the following:     Published     Unfinished     Unlisted     Archived     Disposed   
"""

list_package_versions(domain, format, package, repository; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/package/versions", Dict{String, Any}("domain"=>domain, "format"=>format, "package"=>package, "repository"=>repository); aws_config=aws_config)
list_package_versions(domain, format, package, repository, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/package/versions", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain, "format"=>format, "package"=>package, "repository"=>repository), args)); aws_config=aws_config)

"""
    ListPackages()

 Returns a list of  PackageSummary  objects for packages in a repository that match the request parameters. 

# Required Parameters
- `domain`:  The domain that contains the repository that contains the requested list of packages. 
- `repository`:  The name of the repository from which packages are to be listed. 

# Optional Parameters
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
- `format`:  The format of the packages. The valid package types are:     npm: A Node Package Manager (npm) package.     pypi: A Python Package Index (PyPI) package.     maven: A Maven package that contains compiled code in a distributable format, such as a JAR file.   
- `max-results`:  The maximum number of results to return per page. 
- `namespace`:  The namespace of the package. The package component that specifies its namespace depends on its type. For example:     The namespace of a Maven package is its groupId.     The namespace of an npm package is its scope.     A Python package does not contain a corresponding component, so Python packages do not have a namespace.   
- `next-token`:  The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. 
- `package-prefix`:  A prefix used to filter returned repositories. Only repositories with names that start with repositoryPrefix are returned. 
"""

list_packages(domain, repository; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/packages", Dict{String, Any}("domain"=>domain, "repository"=>repository); aws_config=aws_config)
list_packages(domain, repository, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/packages", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain, "repository"=>repository), args)); aws_config=aws_config)

"""
    ListRepositories()

 Returns a list of  RepositorySummary  objects. Each RepositorySummary contains information about a repository in the specified AWS account and that matches the input parameters. 

# Optional Parameters
- `max-results`:  The maximum number of results to return per page. 
- `next-token`:  The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. 
- `repository-prefix`:  A prefix used to filter returned repositories. Only repositories with names that start with repositoryPrefix are returned.
"""

list_repositories(; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/repositories"; aws_config=aws_config)
list_repositories(args::AbstractDict{String, Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/repositories", args; aws_config=aws_config)

"""
    ListRepositoriesInDomain()

 Returns a list of  RepositorySummary  objects. Each RepositorySummary contains information about a repository in the specified domain and that matches the input parameters. 

# Required Parameters
- `domain`:  The name of the domain that contains the returned list of repositories. 

# Optional Parameters
- `administrator-account`:  Filter the list of repositories to only include those that are managed by the AWS account ID. 
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
- `max-results`:  The maximum number of results to return per page. 
- `next-token`:  The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. 
- `repository-prefix`:  A prefix used to filter returned repositories. Only repositories with names that start with repositoryPrefix are returned. 
"""

list_repositories_in_domain(domain; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/domain/repositories", Dict{String, Any}("domain"=>domain); aws_config=aws_config)
list_repositories_in_domain(domain, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/domain/repositories", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain), args)); aws_config=aws_config)

"""
    PutDomainPermissionsPolicy()

 Sets a resource policy on a domain that specifies permissions to access it. 

# Required Parameters
- `domain`:  The name of the domain on which to set the resource policy. 
- `policyDocument`:  A valid displayable JSON Aspen policy string to be set as the access control resource policy on the provided domain. 

# Optional Parameters
- `domainOwner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
- `policyRevision`:  The current revision of the resource policy to be set. This revision is used for optimistic locking, which prevents others from overwriting your changes to the domain's resource policy. 
"""

put_domain_permissions_policy(domain, policyDocument; aws_config::AWSConfig=global_aws_config()) = codeartifact("PUT", "/v1/domain/permissions/policy", Dict{String, Any}("domain"=>domain, "policyDocument"=>policyDocument); aws_config=aws_config)
put_domain_permissions_policy(domain, policyDocument, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("PUT", "/v1/domain/permissions/policy", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain, "policyDocument"=>policyDocument), args)); aws_config=aws_config)

"""
    PutRepositoryPermissionsPolicy()

 Sets the resource policy on a repository that specifies permissions to access it. 

# Required Parameters
- `domain`:  The name of the domain containing the repository to set the resource policy on. 
- `policyDocument`:  A valid displayable JSON Aspen policy string to be set as the access control resource policy on the provided repository. 
- `repository`:  The name of the repository to set the resource policy on. 

# Optional Parameters
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
- `policyRevision`:  Sets the revision of the resource policy that specifies permissions to access the repository. This revision is used for optimistic locking, which prevents others from overwriting your changes to the repository's resource policy. 
"""

put_repository_permissions_policy(domain, policyDocument, repository; aws_config::AWSConfig=global_aws_config()) = codeartifact("PUT", "/v1/repository/permissions/policy", Dict{String, Any}("domain"=>domain, "policyDocument"=>policyDocument, "repository"=>repository); aws_config=aws_config)
put_repository_permissions_policy(domain, policyDocument, repository, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("PUT", "/v1/repository/permissions/policy", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain, "policyDocument"=>policyDocument, "repository"=>repository), args)); aws_config=aws_config)

"""
    UpdatePackageVersionsStatus()

 Updates the status of one or more versions of a package. 

# Required Parameters
- `domain`:  The domain that contains the repository that contains the package versions with a status to be updated. 
- `format`:  A format that specifies the type of the package with the statuses to update. The valid values are:     npm     pypi     maven   
- `package`:  The name of the package with the version statuses to update. 
- `repository`:  The repository that contains the package versions with the status you want to update. 
- `targetStatus`:  The status you want to change the package version status to. 
- `versions`:  An array of strings that specify the versions of the package with the statuses to update. 

# Optional Parameters
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
- `expectedStatus`:  The package version’s expected status before it is updated. If expectedStatus is provided, the package version's status is updated only if its status at the time UpdatePackageVersionsStatus is called matches expectedStatus. 
- `namespace`:  The namespace of the package. The package component that specifies its namespace depends on its type. For example:     The namespace of a Maven package is its groupId.     The namespace of an npm package is its scope.     A Python package does not contain a corresponding component, so Python packages do not have a namespace.   
- `versionRevisions`:  A map of package versions and package version revisions. The map key is the package version (for example, 3.5.2), and the map value is the package version revision. 
"""

update_package_versions_status(domain, format, package, repository, targetStatus, versions; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/package/versions/update_status", Dict{String, Any}("domain"=>domain, "format"=>format, "package"=>package, "repository"=>repository, "targetStatus"=>targetStatus, "versions"=>versions); aws_config=aws_config)
update_package_versions_status(domain, format, package, repository, targetStatus, versions, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("POST", "/v1/package/versions/update_status", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain, "format"=>format, "package"=>package, "repository"=>repository, "targetStatus"=>targetStatus, "versions"=>versions), args)); aws_config=aws_config)

"""
    UpdateRepository()

 Update the properties of a repository. 

# Required Parameters
- `domain`:  The name of the domain associated with the repository to update. 
- `repository`:  The name of the repository to update. 

# Optional Parameters
- `description`:  An updated repository description. 
- `domain-owner`:  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. 
- `upstreams`:  A list of upstream repositories to associate with the repository. The order of the upstream repositories in the list determines their priority order when AWS CodeArtifact looks for a requested package version. For more information, see Working with upstream repositories. 
"""

update_repository(domain, repository; aws_config::AWSConfig=global_aws_config()) = codeartifact("PUT", "/v1/repository", Dict{String, Any}("domain"=>domain, "repository"=>repository); aws_config=aws_config)
update_repository(domain, repository, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = codeartifact("PUT", "/v1/repository", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("domain"=>domain, "repository"=>repository), args)); aws_config=aws_config)
