# This file is auto-generated by AWSMetadata.jl
using AWS
using AWS.AWSServices: connectparticipant

using AWS.Compat
using AWS.UUIDs
"""
    CreateParticipantConnection()

Creates the participant's connection. Note that ParticipantToken is used for invoking this API instead of ConnectionToken. The participant token is valid for the lifetime of the participant – until the they are part of a contact. The response URL for WEBSOCKET Type has a connect expiry timeout of 100s. Clients must manually connect to the returned websocket URL and subscribe to the desired topic.  For chat, you need to publish the following on the established websocket connection:  {\"topic\":\"aws/subscribe\",\"content\":{\"topics\":[\"aws/chat\"]}}  Upon websocket URL expiry, as specified in the response ConnectionExpiry parameter, clients need to call this API again to obtain a new websocket URL and perform the same steps as before.

# Required Parameters
- `Type`: Type of connection information required.
- `X-Amz-Bearer`: Participant Token as obtained from StartChatContact API response.

"""

create_participant_connection(Type, X_Amz_Bearer; aws_config::AWSConfig=global_aws_config()) = connectparticipant("POST", "/participant/connection", Dict{String, Any}("Type"=>Type, "headers"=>Dict{String, Any}("X-Amz-Bearer"=>X_Amz_Bearer)); aws_config=aws_config)
create_participant_connection(Type, X_Amz_Bearer, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = connectparticipant("POST", "/participant/connection", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Type"=>Type, "headers"=>Dict{String, Any}("X-Amz-Bearer"=>X_Amz_Bearer)), args)); aws_config=aws_config)

"""
    DisconnectParticipant()

Disconnects a participant. Note that ConnectionToken is used for invoking this API instead of ParticipantToken.

# Required Parameters
- `X-Amz-Bearer`: The authentication token associated with the participant's connection.

# Optional Parameters
- `ClientToken`: A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
"""

disconnect_participant(X_Amz_Bearer; aws_config::AWSConfig=global_aws_config()) = connectparticipant("POST", "/participant/disconnect", Dict{String, Any}("ClientToken"=>string(uuid4()), "headers"=>Dict{String, Any}("X-Amz-Bearer"=>X_Amz_Bearer)); aws_config=aws_config)
disconnect_participant(X_Amz_Bearer, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = connectparticipant("POST", "/participant/disconnect", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ClientToken"=>string(uuid4()), "headers"=>Dict{String, Any}("X-Amz-Bearer"=>X_Amz_Bearer)), args)); aws_config=aws_config)

"""
    GetTranscript()

Retrieves a transcript of the session. Note that ConnectionToken is used for invoking this API instead of ParticipantToken.

# Required Parameters
- `X-Amz-Bearer`: The authentication token associated with the participant's connection.

# Optional Parameters
- `ContactId`: The contactId from the current contact chain for which transcript is needed.
- `MaxResults`: The maximum number of results to return in the page. Default: 10. 
- `NextToken`: The pagination token. Use the value returned previously in the next subsequent request to retrieve the next set of results.
- `ScanDirection`: The direction from StartPosition from which to retrieve message. Default: BACKWARD when no StartPosition is provided, FORWARD with StartPosition. 
- `SortOrder`: The sort order for the records. Default: DESCENDING.
- `StartPosition`: A filtering option for where to start.
"""

get_transcript(X_Amz_Bearer; aws_config::AWSConfig=global_aws_config()) = connectparticipant("POST", "/participant/transcript", Dict{String, Any}("headers"=>Dict{String, Any}("X-Amz-Bearer"=>X_Amz_Bearer)); aws_config=aws_config)
get_transcript(X_Amz_Bearer, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = connectparticipant("POST", "/participant/transcript", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("headers"=>Dict{String, Any}("X-Amz-Bearer"=>X_Amz_Bearer)), args)); aws_config=aws_config)

"""
    SendEvent()

Sends an event. Note that ConnectionToken is used for invoking this API instead of ParticipantToken.

# Required Parameters
- `ContentType`: The content type of the request. Supported types are:   application/vnd.amazonaws.connect.event.typing   application/vnd.amazonaws.connect.event.connection.acknowledged  
- `X-Amz-Bearer`: The authentication token associated with the participant's connection.

# Optional Parameters
- `ClientToken`: A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
- `Content`: The content of the event to be sent (for example, message text). This is not yet supported.
"""

send_event(ContentType, X_Amz_Bearer; aws_config::AWSConfig=global_aws_config()) = connectparticipant("POST", "/participant/event", Dict{String, Any}("ContentType"=>ContentType, "ClientToken"=>string(uuid4()), "headers"=>Dict{String, Any}("X-Amz-Bearer"=>X_Amz_Bearer)); aws_config=aws_config)
send_event(ContentType, X_Amz_Bearer, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = connectparticipant("POST", "/participant/event", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ContentType"=>ContentType, "ClientToken"=>string(uuid4()), "headers"=>Dict{String, Any}("X-Amz-Bearer"=>X_Amz_Bearer)), args)); aws_config=aws_config)

"""
    SendMessage()

Sends a message. Note that ConnectionToken is used for invoking this API instead of ParticipantToken.

# Required Parameters
- `Content`: The content of the message.
- `ContentType`: The type of the content. Supported types are text/plain.
- `X-Amz-Bearer`: The authentication token associated with the connection.

# Optional Parameters
- `ClientToken`: A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
"""

send_message(Content, ContentType, X_Amz_Bearer; aws_config::AWSConfig=global_aws_config()) = connectparticipant("POST", "/participant/message", Dict{String, Any}("Content"=>Content, "ContentType"=>ContentType, "ClientToken"=>string(uuid4()), "headers"=>Dict{String, Any}("X-Amz-Bearer"=>X_Amz_Bearer)); aws_config=aws_config)
send_message(Content, ContentType, X_Amz_Bearer, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = connectparticipant("POST", "/participant/message", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Content"=>Content, "ContentType"=>ContentType, "ClientToken"=>string(uuid4()), "headers"=>Dict{String, Any}("X-Amz-Bearer"=>X_Amz_Bearer)), args)); aws_config=aws_config)
