# This file is auto-generated by AWSMetadata.jl
using AWS
using AWS.AWSServices: guardduty
using AWS.Compat
using AWS.UUIDs
"""
    AcceptInvitation()

Accepts the invitation to be monitored by a master GuardDuty account.

# Required Parameters
- `detectorId`: The unique ID of the detector of the GuardDuty member account.
- `invitationId`: The value that is used to validate the master account to the member account.
- `masterId`: The account ID of the master GuardDuty account whose invitation you're accepting.

"""

accept_invitation(detectorId, invitationId, masterId; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/master", Dict{String, Any}("invitationId"=>invitationId, "masterId"=>masterId); aws_config=aws_config)
accept_invitation(detectorId, invitationId, masterId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/master", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("invitationId"=>invitationId, "masterId"=>masterId), args)); aws_config=aws_config)

"""
    ArchiveFindings()

Archives GuardDuty findings that are specified by the list of finding IDs.  Only the master account can archive findings. Member accounts don't have permission to archive findings from their accounts. 

# Required Parameters
- `detectorId`: The ID of the detector that specifies the GuardDuty service whose findings you want to archive.
- `findingIds`: The IDs of the findings that you want to archive.

"""

archive_findings(detectorId, findingIds; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/findings/archive", Dict{String, Any}("findingIds"=>findingIds); aws_config=aws_config)
archive_findings(detectorId, findingIds, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/findings/archive", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("findingIds"=>findingIds), args)); aws_config=aws_config)

"""
    CreateDetector()

Creates a single Amazon GuardDuty detector. A detector is a resource that represents the GuardDuty service. To start using GuardDuty, you must create a detector in each Region where you enable the service. You can have only one detector per account per Region. All data sources are enabled in a new detector by default.

# Required Parameters
- `enable`: A Boolean value that specifies whether the detector is to be enabled.

# Optional Parameters
- `clientToken`: The idempotency token for the create request.
- `dataSources`: An object that describes which data sources will be enabled for the detector.
- `findingPublishingFrequency`: An enum value that specifies how frequently updated findings are exported.
- `tags`: The tags to be added to a new detector resource.
"""

create_detector(enable; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector", Dict{String, Any}("enable"=>enable, "clientToken"=>string(uuid4())); aws_config=aws_config)
create_detector(enable, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("enable"=>enable, "clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    CreateFilter()

Creates a filter using the specified finding criteria.

# Required Parameters
- `detectorId`: The unique ID of the detector of the GuardDuty account that you want to create a filter for.
- `findingCriteria`: Represents the criteria to be used in the filter for querying findings. You can only use the following attributes to query findings:   accountId   region   confidence   id   resource.accessKeyDetails.accessKeyId   resource.accessKeyDetails.principalId   resource.accessKeyDetails.userName   resource.accessKeyDetails.userType   resource.instanceDetails.iamInstanceProfile.id   resource.instanceDetails.imageId   resource.instanceDetails.instanceId   resource.instanceDetails.outpostArn   resource.instanceDetails.networkInterfaces.ipv6Addresses   resource.instanceDetails.networkInterfaces.privateIpAddresses.privateIpAddress   resource.instanceDetails.networkInterfaces.publicDnsName   resource.instanceDetails.networkInterfaces.publicIp   resource.instanceDetails.networkInterfaces.securityGroups.groupId   resource.instanceDetails.networkInterfaces.securityGroups.groupName   resource.instanceDetails.networkInterfaces.subnetId   resource.instanceDetails.networkInterfaces.vpcId   resource.instanceDetails.tags.key   resource.instanceDetails.tags.value   resource.resourceType   service.action.actionType   service.action.awsApiCallAction.api   service.action.awsApiCallAction.callerType   service.action.awsApiCallAction.remoteIpDetails.city.cityName   service.action.awsApiCallAction.remoteIpDetails.country.countryName   service.action.awsApiCallAction.remoteIpDetails.ipAddressV4   service.action.awsApiCallAction.remoteIpDetails.organization.asn   service.action.awsApiCallAction.remoteIpDetails.organization.asnOrg   service.action.awsApiCallAction.serviceName   service.action.dnsRequestAction.domain   service.action.networkConnectionAction.blocked   service.action.networkConnectionAction.connectionDirection   service.action.networkConnectionAction.localPortDetails.port   service.action.networkConnectionAction.protocol   service.action.networkConnectionAction.localIpDetails.ipAddressV4   service.action.networkConnectionAction.remoteIpDetails.city.cityName   service.action.networkConnectionAction.remoteIpDetails.country.countryName   service.action.networkConnectionAction.remoteIpDetails.ipAddressV4   service.action.networkConnectionAction.remoteIpDetails.organization.asn   service.action.networkConnectionAction.remoteIpDetails.organization.asnOrg   service.action.networkConnectionAction.remotePortDetails.port   service.additionalInfo.threatListName   service.archived When this attribute is set to TRUE, only archived findings are listed. When it's set to FALSE, only unarchived findings are listed. When this attribute is not set, all existing findings are listed.   service.resourceRole   severity   type   updatedAt Type: ISO 8601 string format: YYYY-MM-DDTHH:MM:SS.SSSZ or YYYY-MM-DDTHH:MM:SSZ depending on whether the value contains milliseconds.  
- `name`: The name of the filter.

# Optional Parameters
- `action`: Specifies the action that is to be applied to the findings that match the filter.
- `clientToken`: The idempotency token for the create request.
- `description`: The description of the filter.
- `rank`: Specifies the position of the filter in the list of current filters. Also specifies the order in which this filter is applied to the findings.
- `tags`: The tags to be added to a new filter resource.
"""

create_filter(detectorId, findingCriteria, name; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/filter", Dict{String, Any}("findingCriteria"=>findingCriteria, "name"=>name, "clientToken"=>string(uuid4())); aws_config=aws_config)
create_filter(detectorId, findingCriteria, name, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/filter", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("findingCriteria"=>findingCriteria, "name"=>name, "clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    CreateIPSet()

Creates a new IPSet, which is called a trusted IP list in the console user interface. An IPSet is a list of IP addresses that are trusted for secure communication with AWS infrastructure and applications. GuardDuty doesn't generate findings for IP addresses that are included in IPSets. Only users from the master account can use this operation.

# Required Parameters
- `activate`: A Boolean value that indicates whether GuardDuty is to start using the uploaded IPSet.
- `detectorId`: The unique ID of the detector of the GuardDuty account that you want to create an IPSet for.
- `format`: The format of the file that contains the IPSet.
- `location`: The URI of the file that contains the IPSet. For example: https://s3.us-west-2.amazonaws.com/my-bucket/my-object-key.
- `name`: The user-friendly name to identify the IPSet.  Allowed characters are alphanumerics, spaces, hyphens (-), and underscores (_).

# Optional Parameters
- `clientToken`: The idempotency token for the create request.
- `tags`: The tags to be added to a new IP set resource.
"""

create_ipset(activate, detectorId, format, location, name; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/ipset", Dict{String, Any}("activate"=>activate, "format"=>format, "location"=>location, "name"=>name, "clientToken"=>string(uuid4())); aws_config=aws_config)
create_ipset(activate, detectorId, format, location, name, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/ipset", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("activate"=>activate, "format"=>format, "location"=>location, "name"=>name, "clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    CreateMembers()

Creates member accounts of the current AWS account by specifying a list of AWS account IDs. This step is a prerequisite for managing the associated member accounts either by invitation or through an organization. When using Create Members as an organizations delegated administrator this action will enable GuardDuty in the added member accounts, with the exception of the organization master account, which must enable GuardDuty prior to being added as a member. If you are adding accounts by invitation use this action after GuardDuty has been enabled in potential member accounts and before using  Invite Members .

# Required Parameters
- `accountDetails`: A list of account ID and email address pairs of the accounts that you want to associate with the master GuardDuty account.
- `detectorId`: The unique ID of the detector of the GuardDuty account that you want to associate member accounts with.

"""

create_members(accountDetails, detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/member", Dict{String, Any}("accountDetails"=>accountDetails); aws_config=aws_config)
create_members(accountDetails, detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/member", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("accountDetails"=>accountDetails), args)); aws_config=aws_config)

"""
    CreatePublishingDestination()

Creates a publishing destination to export findings to. The resource to export findings to must exist before you use this operation.

# Required Parameters
- `destinationProperties`: The properties of the publishing destination, including the ARNs for the destination and the KMS key used for encryption.
- `destinationType`: The type of resource for the publishing destination. Currently only Amazon S3 buckets are supported.
- `detectorId`: The ID of the GuardDuty detector associated with the publishing destination.

# Optional Parameters
- `clientToken`: The idempotency token for the request.
"""

create_publishing_destination(destinationProperties, destinationType, detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/publishingDestination", Dict{String, Any}("destinationProperties"=>destinationProperties, "destinationType"=>destinationType, "clientToken"=>string(uuid4())); aws_config=aws_config)
create_publishing_destination(destinationProperties, destinationType, detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/publishingDestination", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("destinationProperties"=>destinationProperties, "destinationType"=>destinationType, "clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    CreateSampleFindings()

Generates example findings of types specified by the list of finding types. If 'NULL' is specified for findingTypes, the API generates example findings of all supported finding types.

# Required Parameters
- `detectorId`: The ID of the detector to create sample findings for.

# Optional Parameters
- `findingTypes`: The types of sample findings to generate.
"""

create_sample_findings(detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/findings/create"; aws_config=aws_config)
create_sample_findings(detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/findings/create", args; aws_config=aws_config)

"""
    CreateThreatIntelSet()

Creates a new ThreatIntelSet. ThreatIntelSets consist of known malicious IP addresses. GuardDuty generates findings based on ThreatIntelSets. Only users of the master account can use this operation.

# Required Parameters
- `activate`: A Boolean value that indicates whether GuardDuty is to start using the uploaded ThreatIntelSet.
- `detectorId`: The unique ID of the detector of the GuardDuty account that you want to create a threatIntelSet for.
- `format`: The format of the file that contains the ThreatIntelSet.
- `location`: The URI of the file that contains the ThreatIntelSet. For example: https://s3.us-west-2.amazonaws.com/my-bucket/my-object-key.
- `name`: A user-friendly ThreatIntelSet name displayed in all findings that are generated by activity that involves IP addresses included in this ThreatIntelSet.

# Optional Parameters
- `clientToken`: The idempotency token for the create request.
- `tags`: The tags to be added to a new threat list resource.
"""

create_threat_intel_set(activate, detectorId, format, location, name; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/threatintelset", Dict{String, Any}("activate"=>activate, "format"=>format, "location"=>location, "name"=>name, "clientToken"=>string(uuid4())); aws_config=aws_config)
create_threat_intel_set(activate, detectorId, format, location, name, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/threatintelset", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("activate"=>activate, "format"=>format, "location"=>location, "name"=>name, "clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    DeclineInvitations()

Declines invitations sent to the current member account by AWS accounts specified by their account IDs.

# Required Parameters
- `accountIds`: A list of account IDs of the AWS accounts that sent invitations to the current member account that you want to decline invitations from.

"""

decline_invitations(accountIds; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/invitation/decline", Dict{String, Any}("accountIds"=>accountIds); aws_config=aws_config)
decline_invitations(accountIds, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/invitation/decline", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("accountIds"=>accountIds), args)); aws_config=aws_config)

"""
    DeleteDetector()

Deletes an Amazon GuardDuty detector that is specified by the detector ID.

# Required Parameters
- `detectorId`: The unique ID of the detector that you want to delete.

"""

delete_detector(detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("DELETE", "/detector/$(detectorId)"; aws_config=aws_config)
delete_detector(detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("DELETE", "/detector/$(detectorId)", args; aws_config=aws_config)

"""
    DeleteFilter()

Deletes the filter specified by the filter name.

# Required Parameters
- `detectorId`: The unique ID of the detector that the filter is associated with.
- `filterName`: The name of the filter that you want to delete.

"""

delete_filter(detectorId, filterName; aws_config::AWSConfig=global_aws_config()) = guardduty("DELETE", "/detector/$(detectorId)/filter/$(filterName)"; aws_config=aws_config)
delete_filter(detectorId, filterName, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("DELETE", "/detector/$(detectorId)/filter/$(filterName)", args; aws_config=aws_config)

"""
    DeleteIPSet()

Deletes the IPSet specified by the ipSetId. IPSets are called trusted IP lists in the console user interface.

# Required Parameters
- `detectorId`: The unique ID of the detector associated with the IPSet.
- `ipSetId`: The unique ID of the IPSet to delete.

"""

delete_ipset(detectorId, ipSetId; aws_config::AWSConfig=global_aws_config()) = guardduty("DELETE", "/detector/$(detectorId)/ipset/$(ipSetId)"; aws_config=aws_config)
delete_ipset(detectorId, ipSetId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("DELETE", "/detector/$(detectorId)/ipset/$(ipSetId)", args; aws_config=aws_config)

"""
    DeleteInvitations()

Deletes invitations sent to the current member account by AWS accounts specified by their account IDs.

# Required Parameters
- `accountIds`: A list of account IDs of the AWS accounts that sent invitations to the current member account that you want to delete invitations from.

"""

delete_invitations(accountIds; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/invitation/delete", Dict{String, Any}("accountIds"=>accountIds); aws_config=aws_config)
delete_invitations(accountIds, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/invitation/delete", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("accountIds"=>accountIds), args)); aws_config=aws_config)

"""
    DeleteMembers()

Deletes GuardDuty member accounts (to the current GuardDuty master account) specified by the account IDs.

# Required Parameters
- `accountIds`: A list of account IDs of the GuardDuty member accounts that you want to delete.
- `detectorId`: The unique ID of the detector of the GuardDuty account whose members you want to delete.

"""

delete_members(accountIds, detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/member/delete", Dict{String, Any}("accountIds"=>accountIds); aws_config=aws_config)
delete_members(accountIds, detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/member/delete", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("accountIds"=>accountIds), args)); aws_config=aws_config)

"""
    DeletePublishingDestination()

Deletes the publishing definition with the specified destinationId.

# Required Parameters
- `destinationId`: The ID of the publishing destination to delete.
- `detectorId`: The unique ID of the detector associated with the publishing destination to delete.

"""

delete_publishing_destination(destinationId, detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("DELETE", "/detector/$(detectorId)/publishingDestination/$(destinationId)"; aws_config=aws_config)
delete_publishing_destination(destinationId, detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("DELETE", "/detector/$(detectorId)/publishingDestination/$(destinationId)", args; aws_config=aws_config)

"""
    DeleteThreatIntelSet()

Deletes the ThreatIntelSet specified by the ThreatIntelSet ID.

# Required Parameters
- `detectorId`: The unique ID of the detector that the threatIntelSet is associated with.
- `threatIntelSetId`: The unique ID of the threatIntelSet that you want to delete.

"""

delete_threat_intel_set(detectorId, threatIntelSetId; aws_config::AWSConfig=global_aws_config()) = guardduty("DELETE", "/detector/$(detectorId)/threatintelset/$(threatIntelSetId)"; aws_config=aws_config)
delete_threat_intel_set(detectorId, threatIntelSetId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("DELETE", "/detector/$(detectorId)/threatintelset/$(threatIntelSetId)", args; aws_config=aws_config)

"""
    DescribeOrganizationConfiguration()

Returns information about the account selected as the delegated administrator for GuardDuty.

# Required Parameters
- `detectorId`: The ID of the detector to retrieve information about the delegated administrator from.

"""

describe_organization_configuration(detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/detector/$(detectorId)/admin"; aws_config=aws_config)
describe_organization_configuration(detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/detector/$(detectorId)/admin", args; aws_config=aws_config)

"""
    DescribePublishingDestination()

Returns information about the publishing destination specified by the provided destinationId.

# Required Parameters
- `destinationId`: The ID of the publishing destination to retrieve.
- `detectorId`: The unique ID of the detector associated with the publishing destination to retrieve.

"""

describe_publishing_destination(destinationId, detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/detector/$(detectorId)/publishingDestination/$(destinationId)"; aws_config=aws_config)
describe_publishing_destination(destinationId, detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/detector/$(detectorId)/publishingDestination/$(destinationId)", args; aws_config=aws_config)

"""
    DisableOrganizationAdminAccount()

Disables an AWS account within the Organization as the GuardDuty delegated administrator.

# Required Parameters
- `adminAccountId`: The AWS Account ID for the organizations account to be disabled as a GuardDuty delegated administrator.

"""

disable_organization_admin_account(adminAccountId; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/admin/disable", Dict{String, Any}("adminAccountId"=>adminAccountId); aws_config=aws_config)
disable_organization_admin_account(adminAccountId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/admin/disable", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("adminAccountId"=>adminAccountId), args)); aws_config=aws_config)

"""
    DisassociateFromMasterAccount()

Disassociates the current GuardDuty member account from its master account.

# Required Parameters
- `detectorId`: The unique ID of the detector of the GuardDuty member account.

"""

disassociate_from_master_account(detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/master/disassociate"; aws_config=aws_config)
disassociate_from_master_account(detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/master/disassociate", args; aws_config=aws_config)

"""
    DisassociateMembers()

Disassociates GuardDuty member accounts (to the current GuardDuty master account) specified by the account IDs.

# Required Parameters
- `accountIds`: A list of account IDs of the GuardDuty member accounts that you want to disassociate from the master account.
- `detectorId`: The unique ID of the detector of the GuardDuty account whose members you want to disassociate from the master account.

"""

disassociate_members(accountIds, detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/member/disassociate", Dict{String, Any}("accountIds"=>accountIds); aws_config=aws_config)
disassociate_members(accountIds, detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/member/disassociate", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("accountIds"=>accountIds), args)); aws_config=aws_config)

"""
    EnableOrganizationAdminAccount()

Enables an AWS account within the organization as the GuardDuty delegated administrator.

# Required Parameters
- `adminAccountId`: The AWS Account ID for the organization account to be enabled as a GuardDuty delegated administrator.

"""

enable_organization_admin_account(adminAccountId; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/admin/enable", Dict{String, Any}("adminAccountId"=>adminAccountId); aws_config=aws_config)
enable_organization_admin_account(adminAccountId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/admin/enable", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("adminAccountId"=>adminAccountId), args)); aws_config=aws_config)

"""
    GetDetector()

Retrieves an Amazon GuardDuty detector specified by the detectorId.

# Required Parameters
- `detectorId`: The unique ID of the detector that you want to get.

"""

get_detector(detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/detector/$(detectorId)"; aws_config=aws_config)
get_detector(detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/detector/$(detectorId)", args; aws_config=aws_config)

"""
    GetFilter()

Returns the details of the filter specified by the filter name.

# Required Parameters
- `detectorId`: The unique ID of the detector that the filter is associated with.
- `filterName`: The name of the filter you want to get.

"""

get_filter(detectorId, filterName; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/detector/$(detectorId)/filter/$(filterName)"; aws_config=aws_config)
get_filter(detectorId, filterName, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/detector/$(detectorId)/filter/$(filterName)", args; aws_config=aws_config)

"""
    GetFindings()

Describes Amazon GuardDuty findings specified by finding IDs.

# Required Parameters
- `detectorId`: The ID of the detector that specifies the GuardDuty service whose findings you want to retrieve.
- `findingIds`: The IDs of the findings that you want to retrieve.

# Optional Parameters
- `sortCriteria`: Represents the criteria used for sorting findings.
"""

get_findings(detectorId, findingIds; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/findings/get", Dict{String, Any}("findingIds"=>findingIds); aws_config=aws_config)
get_findings(detectorId, findingIds, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/findings/get", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("findingIds"=>findingIds), args)); aws_config=aws_config)

"""
    GetFindingsStatistics()

Lists Amazon GuardDuty findings statistics for the specified detector ID.

# Required Parameters
- `detectorId`: The ID of the detector that specifies the GuardDuty service whose findings' statistics you want to retrieve.
- `findingStatisticTypes`: The types of finding statistics to retrieve.

# Optional Parameters
- `findingCriteria`: Represents the criteria that is used for querying findings.
"""

get_findings_statistics(detectorId, findingStatisticTypes; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/findings/statistics", Dict{String, Any}("findingStatisticTypes"=>findingStatisticTypes); aws_config=aws_config)
get_findings_statistics(detectorId, findingStatisticTypes, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/findings/statistics", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("findingStatisticTypes"=>findingStatisticTypes), args)); aws_config=aws_config)

"""
    GetIPSet()

Retrieves the IPSet specified by the ipSetId.

# Required Parameters
- `detectorId`: The unique ID of the detector that the IPSet is associated with.
- `ipSetId`: The unique ID of the IPSet to retrieve.

"""

get_ipset(detectorId, ipSetId; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/detector/$(detectorId)/ipset/$(ipSetId)"; aws_config=aws_config)
get_ipset(detectorId, ipSetId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/detector/$(detectorId)/ipset/$(ipSetId)", args; aws_config=aws_config)

"""
    GetInvitationsCount()

Returns the count of all GuardDuty membership invitations that were sent to the current member account except the currently accepted invitation.

"""

get_invitations_count(; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/invitation/count"; aws_config=aws_config)
get_invitations_count(args::AbstractDict{String, Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/invitation/count", args; aws_config=aws_config)

"""
    GetMasterAccount()

Provides the details for the GuardDuty master account associated with the current GuardDuty member account.

# Required Parameters
- `detectorId`: The unique ID of the detector of the GuardDuty member account.

"""

get_master_account(detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/detector/$(detectorId)/master"; aws_config=aws_config)
get_master_account(detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/detector/$(detectorId)/master", args; aws_config=aws_config)

"""
    GetMemberDetectors()

Describes which data sources are enabled for the member account's detector.

# Required Parameters
- `accountIds`: The account ID of the member account.
- `detectorId`: The detector ID for the master account.

"""

get_member_detectors(accountIds, detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/member/detector/get", Dict{String, Any}("accountIds"=>accountIds); aws_config=aws_config)
get_member_detectors(accountIds, detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/member/detector/get", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("accountIds"=>accountIds), args)); aws_config=aws_config)

"""
    GetMembers()

Retrieves GuardDuty member accounts (to the current GuardDuty master account) specified by the account IDs.

# Required Parameters
- `accountIds`: A list of account IDs of the GuardDuty member accounts that you want to describe.
- `detectorId`: The unique ID of the detector of the GuardDuty account whose members you want to retrieve.

"""

get_members(accountIds, detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/member/get", Dict{String, Any}("accountIds"=>accountIds); aws_config=aws_config)
get_members(accountIds, detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/member/get", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("accountIds"=>accountIds), args)); aws_config=aws_config)

"""
    GetThreatIntelSet()

Retrieves the ThreatIntelSet that is specified by the ThreatIntelSet ID.

# Required Parameters
- `detectorId`: The unique ID of the detector that the threatIntelSet is associated with.
- `threatIntelSetId`: The unique ID of the threatIntelSet that you want to get.

"""

get_threat_intel_set(detectorId, threatIntelSetId; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/detector/$(detectorId)/threatintelset/$(threatIntelSetId)"; aws_config=aws_config)
get_threat_intel_set(detectorId, threatIntelSetId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/detector/$(detectorId)/threatintelset/$(threatIntelSetId)", args; aws_config=aws_config)

"""
    GetUsageStatistics()

Lists Amazon GuardDuty usage statistics over the last 30 days for the specified detector ID. For newly enabled detectors or data sources the cost returned will include only the usage so far under 30 days, this may differ from the cost metrics in the console, which projects usage over 30 days to provide a monthly cost estimate. For more information see Understanding How Usage Costs are Calculated.

# Required Parameters
- `detectorId`: The ID of the detector that specifies the GuardDuty service whose usage statistics you want to retrieve.
- `usageCriteria`: Represents the criteria used for querying usage.
- `usageStatisticsType`: The type of usage statistics to retrieve.

# Optional Parameters
- `maxResults`: The maximum number of results to return in the response.
- `nextToken`: A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request to a list action. For subsequent calls, use the NextToken value returned from the previous request to continue listing results after the first page.
- `unit`: The currency unit you would like to view your usage statistics in. Current valid values are USD.
"""

get_usage_statistics(detectorId, usageCriteria, usageStatisticsType; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/usage/statistics", Dict{String, Any}("usageCriteria"=>usageCriteria, "usageStatisticsType"=>usageStatisticsType); aws_config=aws_config)
get_usage_statistics(detectorId, usageCriteria, usageStatisticsType, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/usage/statistics", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("usageCriteria"=>usageCriteria, "usageStatisticsType"=>usageStatisticsType), args)); aws_config=aws_config)

"""
    InviteMembers()

Invites other AWS accounts (created as members of the current AWS account by CreateMembers) to enable GuardDuty, and allow the current AWS account to view and manage these accounts' GuardDuty findings on their behalf as the master account.

# Required Parameters
- `accountIds`: A list of account IDs of the accounts that you want to invite to GuardDuty as members.
- `detectorId`: The unique ID of the detector of the GuardDuty account that you want to invite members with.

# Optional Parameters
- `disableEmailNotification`: A Boolean value that specifies whether you want to disable email notification to the accounts that you are inviting to GuardDuty as members.
- `message`: The invitation message that you want to send to the accounts that you're inviting to GuardDuty as members.
"""

invite_members(accountIds, detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/member/invite", Dict{String, Any}("accountIds"=>accountIds); aws_config=aws_config)
invite_members(accountIds, detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/member/invite", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("accountIds"=>accountIds), args)); aws_config=aws_config)

"""
    ListDetectors()

Lists detectorIds of all the existing Amazon GuardDuty detector resources.

# Optional Parameters
- `maxResults`: You can use this parameter to indicate the maximum number of items that you want in the response. The default value is 50. The maximum value is 50.
- `nextToken`: You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing data.
"""

list_detectors(; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/detector"; aws_config=aws_config)
list_detectors(args::AbstractDict{String, Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/detector", args; aws_config=aws_config)

"""
    ListFilters()

Returns a paginated list of the current filters.

# Required Parameters
- `detectorId`: The unique ID of the detector that the filter is associated with.

# Optional Parameters
- `maxResults`: You can use this parameter to indicate the maximum number of items that you want in the response. The default value is 50. The maximum value is 50.
- `nextToken`: You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing data.
"""

list_filters(detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/detector/$(detectorId)/filter"; aws_config=aws_config)
list_filters(detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/detector/$(detectorId)/filter", args; aws_config=aws_config)

"""
    ListFindings()

Lists Amazon GuardDuty findings for the specified detector ID.

# Required Parameters
- `detectorId`: The ID of the detector that specifies the GuardDuty service whose findings you want to list.

# Optional Parameters
- `findingCriteria`: Represents the criteria used for querying findings. Valid values include:   JSON field name   accountId   region   confidence   id   resource.accessKeyDetails.accessKeyId   resource.accessKeyDetails.principalId   resource.accessKeyDetails.userName   resource.accessKeyDetails.userType   resource.instanceDetails.iamInstanceProfile.id   resource.instanceDetails.imageId   resource.instanceDetails.instanceId   resource.instanceDetails.networkInterfaces.ipv6Addresses   resource.instanceDetails.networkInterfaces.privateIpAddresses.privateIpAddress   resource.instanceDetails.networkInterfaces.publicDnsName   resource.instanceDetails.networkInterfaces.publicIp   resource.instanceDetails.networkInterfaces.securityGroups.groupId   resource.instanceDetails.networkInterfaces.securityGroups.groupName   resource.instanceDetails.networkInterfaces.subnetId   resource.instanceDetails.networkInterfaces.vpcId   resource.instanceDetails.tags.key   resource.instanceDetails.tags.value   resource.resourceType   service.action.actionType   service.action.awsApiCallAction.api   service.action.awsApiCallAction.callerType   service.action.awsApiCallAction.remoteIpDetails.city.cityName   service.action.awsApiCallAction.remoteIpDetails.country.countryName   service.action.awsApiCallAction.remoteIpDetails.ipAddressV4   service.action.awsApiCallAction.remoteIpDetails.organization.asn   service.action.awsApiCallAction.remoteIpDetails.organization.asnOrg   service.action.awsApiCallAction.serviceName   service.action.dnsRequestAction.domain   service.action.networkConnectionAction.blocked   service.action.networkConnectionAction.connectionDirection   service.action.networkConnectionAction.localPortDetails.port   service.action.networkConnectionAction.protocol   service.action.networkConnectionAction.remoteIpDetails.city.cityName   service.action.networkConnectionAction.remoteIpDetails.country.countryName   service.action.networkConnectionAction.remoteIpDetails.ipAddressV4   service.action.networkConnectionAction.remoteIpDetails.organization.asn   service.action.networkConnectionAction.remoteIpDetails.organization.asnOrg   service.action.networkConnectionAction.remotePortDetails.port   service.additionalInfo.threatListName   service.archived When this attribute is set to 'true', only archived findings are listed. When it's set to 'false', only unarchived findings are listed. When this attribute is not set, all existing findings are listed.   service.resourceRole   severity   type   updatedAt Type: Timestamp in Unix Epoch millisecond format: 1486685375000  
- `maxResults`: You can use this parameter to indicate the maximum number of items you want in the response. The default value is 50. The maximum value is 50.
- `nextToken`: You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing data.
- `sortCriteria`: Represents the criteria used for sorting findings.
"""

list_findings(detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/findings"; aws_config=aws_config)
list_findings(detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/findings", args; aws_config=aws_config)

"""
    ListIPSets()

Lists the IPSets of the GuardDuty service specified by the detector ID. If you use this operation from a member account, the IPSets returned are the IPSets from the associated master account.

# Required Parameters
- `detectorId`: The unique ID of the detector that the IPSet is associated with.

# Optional Parameters
- `maxResults`: You can use this parameter to indicate the maximum number of items you want in the response. The default value is 50. The maximum value is 50.
- `nextToken`: You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing data.
"""

list_ipsets(detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/detector/$(detectorId)/ipset"; aws_config=aws_config)
list_ipsets(detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/detector/$(detectorId)/ipset", args; aws_config=aws_config)

"""
    ListInvitations()

Lists all GuardDuty membership invitations that were sent to the current AWS account.

# Optional Parameters
- `maxResults`: You can use this parameter to indicate the maximum number of items that you want in the response. The default value is 50. The maximum value is 50.
- `nextToken`: You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing data.
"""

list_invitations(; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/invitation"; aws_config=aws_config)
list_invitations(args::AbstractDict{String, Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/invitation", args; aws_config=aws_config)

"""
    ListMembers()

Lists details about all member accounts for the current GuardDuty master account.

# Required Parameters
- `detectorId`: The unique ID of the detector the member is associated with.

# Optional Parameters
- `maxResults`: You can use this parameter to indicate the maximum number of items you want in the response. The default value is 50. The maximum value is 50.
- `nextToken`: You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing data.
- `onlyAssociated`: Specifies whether to only return associated members or to return all members (including members who haven't been invited yet or have been disassociated).
"""

list_members(detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/detector/$(detectorId)/member"; aws_config=aws_config)
list_members(detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/detector/$(detectorId)/member", args; aws_config=aws_config)

"""
    ListOrganizationAdminAccounts()

Lists the accounts configured as GuardDuty delegated administrators.

# Optional Parameters
- `maxResults`: The maximum number of results to return in the response.
- `nextToken`: A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request to a list action. For subsequent calls, use the NextToken value returned from the previous request to continue listing results after the first page.
"""

list_organization_admin_accounts(; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/admin"; aws_config=aws_config)
list_organization_admin_accounts(args::AbstractDict{String, Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/admin", args; aws_config=aws_config)

"""
    ListPublishingDestinations()

Returns a list of publishing destinations associated with the specified dectectorId.

# Required Parameters
- `detectorId`: The ID of the detector to retrieve publishing destinations for.

# Optional Parameters
- `maxResults`: The maximum number of results to return in the response.
- `nextToken`: A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request to a list action. For subsequent calls, use the NextToken value returned from the previous request to continue listing results after the first page.
"""

list_publishing_destinations(detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/detector/$(detectorId)/publishingDestination"; aws_config=aws_config)
list_publishing_destinations(detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/detector/$(detectorId)/publishingDestination", args; aws_config=aws_config)

"""
    ListTagsForResource()

Lists tags for a resource. Tagging is currently supported for detectors, finding filters, IP sets, and threat intel sets, with a limit of 50 tags per resource. When invoked, this operation returns all assigned tags for a given resource.

# Required Parameters
- `resourceArn`: The Amazon Resource Name (ARN) for the given GuardDuty resource. 

"""

list_tags_for_resource(resourceArn; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/tags/$(resourceArn)"; aws_config=aws_config)
list_tags_for_resource(resourceArn, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/tags/$(resourceArn)", args; aws_config=aws_config)

"""
    ListThreatIntelSets()

Lists the ThreatIntelSets of the GuardDuty service specified by the detector ID. If you use this operation from a member account, the ThreatIntelSets associated with the master account are returned.

# Required Parameters
- `detectorId`: The unique ID of the detector that the threatIntelSet is associated with.

# Optional Parameters
- `maxResults`: You can use this parameter to indicate the maximum number of items that you want in the response. The default value is 50. The maximum value is 50.
- `nextToken`: You can use this parameter to paginate results in the response. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing data.
"""

list_threat_intel_sets(detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/detector/$(detectorId)/threatintelset"; aws_config=aws_config)
list_threat_intel_sets(detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("GET", "/detector/$(detectorId)/threatintelset", args; aws_config=aws_config)

"""
    StartMonitoringMembers()

Turns on GuardDuty monitoring of the specified member accounts. Use this operation to restart monitoring of accounts that you stopped monitoring with the StopMonitoringMembers operation.

# Required Parameters
- `accountIds`: A list of account IDs of the GuardDuty member accounts to start monitoring.
- `detectorId`: The unique ID of the detector of the GuardDuty master account associated with the member accounts to monitor.

"""

start_monitoring_members(accountIds, detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/member/start", Dict{String, Any}("accountIds"=>accountIds); aws_config=aws_config)
start_monitoring_members(accountIds, detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/member/start", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("accountIds"=>accountIds), args)); aws_config=aws_config)

"""
    StopMonitoringMembers()

Stops GuardDuty monitoring for the specified member accounts. Use the StartMonitoringMembers operation to restart monitoring for those accounts.

# Required Parameters
- `accountIds`: A list of account IDs for the member accounts to stop monitoring.
- `detectorId`: The unique ID of the detector associated with the GuardDuty master account that is monitoring member accounts.

"""

stop_monitoring_members(accountIds, detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/member/stop", Dict{String, Any}("accountIds"=>accountIds); aws_config=aws_config)
stop_monitoring_members(accountIds, detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/member/stop", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("accountIds"=>accountIds), args)); aws_config=aws_config)

"""
    TagResource()

Adds tags to a resource.

# Required Parameters
- `resourceArn`: The Amazon Resource Name (ARN) for the GuardDuty resource to apply a tag to.
- `tags`: The tags to be added to a resource.

"""

tag_resource(resourceArn, tags; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/tags/$(resourceArn)", Dict{String, Any}("tags"=>tags); aws_config=aws_config)
tag_resource(resourceArn, tags, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/tags/$(resourceArn)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("tags"=>tags), args)); aws_config=aws_config)

"""
    UnarchiveFindings()

Unarchives GuardDuty findings specified by the findingIds.

# Required Parameters
- `detectorId`: The ID of the detector associated with the findings to unarchive.
- `findingIds`: The IDs of the findings to unarchive.

"""

unarchive_findings(detectorId, findingIds; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/findings/unarchive", Dict{String, Any}("findingIds"=>findingIds); aws_config=aws_config)
unarchive_findings(detectorId, findingIds, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/findings/unarchive", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("findingIds"=>findingIds), args)); aws_config=aws_config)

"""
    UntagResource()

Removes tags from a resource.

# Required Parameters
- `resourceArn`: The Amazon Resource Name (ARN) for the resource to remove tags from.
- `tagKeys`: The tag keys to remove from the resource.

"""

untag_resource(resourceArn, tagKeys; aws_config::AWSConfig=global_aws_config()) = guardduty("DELETE", "/tags/$(resourceArn)", Dict{String, Any}("tagKeys"=>tagKeys); aws_config=aws_config)
untag_resource(resourceArn, tagKeys, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("DELETE", "/tags/$(resourceArn)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("tagKeys"=>tagKeys), args)); aws_config=aws_config)

"""
    UpdateDetector()

Updates the Amazon GuardDuty detector specified by the detectorId.

# Required Parameters
- `detectorId`: The unique ID of the detector to update.

# Optional Parameters
- `dataSources`: An object that describes which data sources will be updated.
- `enable`: Specifies whether the detector is enabled or not enabled.
- `findingPublishingFrequency`: An enum value that specifies how frequently findings are exported, such as to CloudWatch Events.
"""

update_detector(detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)"; aws_config=aws_config)
update_detector(detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)", args; aws_config=aws_config)

"""
    UpdateFilter()

Updates the filter specified by the filter name.

# Required Parameters
- `detectorId`: The unique ID of the detector that specifies the GuardDuty service where you want to update a filter.
- `filterName`: The name of the filter.

# Optional Parameters
- `action`: Specifies the action that is to be applied to the findings that match the filter.
- `description`: The description of the filter.
- `findingCriteria`: Represents the criteria to be used in the filter for querying findings.
- `rank`: Specifies the position of the filter in the list of current filters. Also specifies the order in which this filter is applied to the findings.
"""

update_filter(detectorId, filterName; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/filter/$(filterName)"; aws_config=aws_config)
update_filter(detectorId, filterName, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/filter/$(filterName)", args; aws_config=aws_config)

"""
    UpdateFindingsFeedback()

Marks the specified GuardDuty findings as useful or not useful.

# Required Parameters
- `detectorId`: The ID of the detector associated with the findings to update feedback for.
- `feedback`: The feedback for the finding.
- `findingIds`: The IDs of the findings that you want to mark as useful or not useful.

# Optional Parameters
- `comments`: Additional feedback about the GuardDuty findings.
"""

update_findings_feedback(detectorId, feedback, findingIds; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/findings/feedback", Dict{String, Any}("feedback"=>feedback, "findingIds"=>findingIds); aws_config=aws_config)
update_findings_feedback(detectorId, feedback, findingIds, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/findings/feedback", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("feedback"=>feedback, "findingIds"=>findingIds), args)); aws_config=aws_config)

"""
    UpdateIPSet()

Updates the IPSet specified by the IPSet ID.

# Required Parameters
- `detectorId`: The detectorID that specifies the GuardDuty service whose IPSet you want to update.
- `ipSetId`: The unique ID that specifies the IPSet that you want to update.

# Optional Parameters
- `activate`: The updated Boolean value that specifies whether the IPSet is active or not.
- `location`: The updated URI of the file that contains the IPSet. For example: https://s3.us-west-2.amazonaws.com/my-bucket/my-object-key.
- `name`: The unique ID that specifies the IPSet that you want to update.
"""

update_ipset(detectorId, ipSetId; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/ipset/$(ipSetId)"; aws_config=aws_config)
update_ipset(detectorId, ipSetId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/ipset/$(ipSetId)", args; aws_config=aws_config)

"""
    UpdateMemberDetectors()

Contains information on member accounts to be updated.

# Required Parameters
- `accountIds`: A list of member account IDs to be updated.
- `detectorId`: The detector ID of the master account.

# Optional Parameters
- `dataSources`: An object describes which data sources will be updated.
"""

update_member_detectors(accountIds, detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/member/detector/update", Dict{String, Any}("accountIds"=>accountIds); aws_config=aws_config)
update_member_detectors(accountIds, detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/member/detector/update", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("accountIds"=>accountIds), args)); aws_config=aws_config)

"""
    UpdateOrganizationConfiguration()

Updates the delegated administrator account with the values provided.

# Required Parameters
- `autoEnable`: Indicates whether to automatically enable member accounts in the organization.
- `detectorId`: The ID of the detector to update the delegated administrator for.

# Optional Parameters
- `dataSources`: An object describes which data sources will be updated.
"""

update_organization_configuration(autoEnable, detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/admin", Dict{String, Any}("autoEnable"=>autoEnable); aws_config=aws_config)
update_organization_configuration(autoEnable, detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/admin", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("autoEnable"=>autoEnable), args)); aws_config=aws_config)

"""
    UpdatePublishingDestination()

Updates information about the publishing destination specified by the destinationId.

# Required Parameters
- `destinationId`: The ID of the publishing destination to update.
- `detectorId`: The ID of the detector associated with the publishing destinations to update.

# Optional Parameters
- `destinationProperties`: A DestinationProperties object that includes the DestinationArn and KmsKeyArn of the publishing destination.
"""

update_publishing_destination(destinationId, detectorId; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/publishingDestination/$(destinationId)"; aws_config=aws_config)
update_publishing_destination(destinationId, detectorId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/publishingDestination/$(destinationId)", args; aws_config=aws_config)

"""
    UpdateThreatIntelSet()

Updates the ThreatIntelSet specified by the ThreatIntelSet ID.

# Required Parameters
- `detectorId`: The detectorID that specifies the GuardDuty service whose ThreatIntelSet you want to update.
- `threatIntelSetId`: The unique ID that specifies the ThreatIntelSet that you want to update.

# Optional Parameters
- `activate`: The updated Boolean value that specifies whether the ThreateIntelSet is active or not.
- `location`: The updated URI of the file that contains the ThreateIntelSet. For example: https://s3.us-west-2.amazonaws.com/my-bucket/my-object-key.
- `name`: The unique ID that specifies the ThreatIntelSet that you want to update.
"""

update_threat_intel_set(detectorId, threatIntelSetId; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/threatintelset/$(threatIntelSetId)"; aws_config=aws_config)
update_threat_intel_set(detectorId, threatIntelSetId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = guardduty("POST", "/detector/$(detectorId)/threatintelset/$(threatIntelSetId)", args; aws_config=aws_config)
