# This file is auto-generated by AWSMetadata.jl
using AWS
using AWS.AWSServices: iotsitewise

using AWS.Compat
using AWS.UUIDs
"""
    AssociateAssets()

Associates a child asset with the given parent asset through a hierarchy defined in the parent asset's model. For more information, see Associating assets in the AWS IoT SiteWise User Guide.

# Required Parameters
- `assetId`: The ID of the parent asset.
- `childAssetId`: The ID of the child asset to be associated.
- `hierarchyId`: The ID of a hierarchy in the parent asset's model. Hierarchies allow different groupings of assets to be formed that all come from the same asset model. For more information, see Asset hierarchies in the AWS IoT SiteWise User Guide.

# Optional Parameters
- `clientToken`: A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
"""

associate_assets(assetId, childAssetId, hierarchyId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/assets/$(assetId)/associate", Dict{String, Any}("childAssetId"=>childAssetId, "hierarchyId"=>hierarchyId, "clientToken"=>string(uuid4())); aws_config=aws_config)
associate_assets(assetId, childAssetId, hierarchyId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/assets/$(assetId)/associate", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("childAssetId"=>childAssetId, "hierarchyId"=>hierarchyId, "clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    BatchAssociateProjectAssets()

Associates a group (batch) of assets with an AWS IoT SiteWise Monitor project.

# Required Parameters
- `assetIds`: The IDs of the assets to be associated to the project.
- `projectId`: The ID of the project to which to associate the assets.

# Optional Parameters
- `clientToken`: A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
"""

batch_associate_project_assets(assetIds, projectId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/projects/$(projectId)/assets/associate", Dict{String, Any}("assetIds"=>assetIds, "clientToken"=>string(uuid4())); aws_config=aws_config)
batch_associate_project_assets(assetIds, projectId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/projects/$(projectId)/assets/associate", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("assetIds"=>assetIds, "clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    BatchDisassociateProjectAssets()

Disassociates a group (batch) of assets from an AWS IoT SiteWise Monitor project.

# Required Parameters
- `assetIds`: The IDs of the assets to be disassociated from the project.
- `projectId`: The ID of the project from which to disassociate the assets.

# Optional Parameters
- `clientToken`: A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
"""

batch_disassociate_project_assets(assetIds, projectId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/projects/$(projectId)/assets/disassociate", Dict{String, Any}("assetIds"=>assetIds, "clientToken"=>string(uuid4())); aws_config=aws_config)
batch_disassociate_project_assets(assetIds, projectId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/projects/$(projectId)/assets/disassociate", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("assetIds"=>assetIds, "clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    BatchPutAssetPropertyValue()

Sends a list of asset property values to AWS IoT SiteWise. Each value is a timestamp-quality-value (TQV) data point. For more information, see Ingesting data using the API in the AWS IoT SiteWise User Guide. To identify an asset property, you must specify one of the following:   The assetId and propertyId of an asset property.   A propertyAlias, which is a data stream alias (for example, /company/windfarm/3/turbine/7/temperature). To define an asset property's alias, see UpdateAssetProperty.    With respect to Unix epoch time, AWS IoT SiteWise accepts only TQVs that have a timestamp of no more than 15 minutes in the past and no more than 5 minutes in the future. AWS IoT SiteWise rejects timestamps outside of the inclusive range of [-15, +5] minutes and returns a TimestampOutOfRangeException error. For each asset property, AWS IoT SiteWise overwrites TQVs with duplicate timestamps unless the newer TQV has a different quality. For example, if you store a TQV {T1, GOOD, V1}, then storing {T1, GOOD, V2} replaces the existing TQV.  AWS IoT SiteWise authorizes access to each BatchPutAssetPropertyValue entry individually. For more information, see BatchPutAssetPropertyValue authorization in the AWS IoT SiteWise User Guide.

# Required Parameters
- `entries`: The list of asset property value entries for the batch put request. You can specify up to 10 entries per request.

"""

batch_put_asset_property_value(entries; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/properties", Dict{String, Any}("entries"=>entries); aws_config=aws_config)
batch_put_asset_property_value(entries, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/properties", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("entries"=>entries), args)); aws_config=aws_config)

"""
    CreateAccessPolicy()

Creates an access policy that grants the specified AWS Single Sign-On user or group access to the specified AWS IoT SiteWise Monitor portal or project resource.

# Required Parameters
- `accessPolicyIdentity`: The identity for this access policy. Choose either a user or a group but not both.
- `accessPolicyPermission`: The permission level for this access policy. Note that a project ADMINISTRATOR is also known as a project owner.
- `accessPolicyResource`: The AWS IoT SiteWise Monitor resource for this access policy. Choose either portal or project but not both.

# Optional Parameters
- `clientToken`: A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
- `tags`: A list of key-value pairs that contain metadata for the access policy. For more information, see Tagging your AWS IoT SiteWise resources in the AWS IoT SiteWise User Guide.
"""

create_access_policy(accessPolicyIdentity, accessPolicyPermission, accessPolicyResource; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/access-policies", Dict{String, Any}("accessPolicyIdentity"=>accessPolicyIdentity, "accessPolicyPermission"=>accessPolicyPermission, "accessPolicyResource"=>accessPolicyResource, "clientToken"=>string(uuid4())); aws_config=aws_config)
create_access_policy(accessPolicyIdentity, accessPolicyPermission, accessPolicyResource, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/access-policies", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("accessPolicyIdentity"=>accessPolicyIdentity, "accessPolicyPermission"=>accessPolicyPermission, "accessPolicyResource"=>accessPolicyResource, "clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    CreateAsset()

Creates an asset from an existing asset model. For more information, see Creating assets in the AWS IoT SiteWise User Guide.

# Required Parameters
- `assetModelId`: The ID of the asset model from which to create the asset.
- `assetName`: A unique, friendly name for the asset.

# Optional Parameters
- `clientToken`: A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
- `tags`: A list of key-value pairs that contain metadata for the asset. For more information, see Tagging your AWS IoT SiteWise resources in the AWS IoT SiteWise User Guide.
"""

create_asset(assetModelId, assetName; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/assets", Dict{String, Any}("assetModelId"=>assetModelId, "assetName"=>assetName, "clientToken"=>string(uuid4())); aws_config=aws_config)
create_asset(assetModelId, assetName, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/assets", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("assetModelId"=>assetModelId, "assetName"=>assetName, "clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    CreateAssetModel()

Creates an asset model from specified property and hierarchy definitions. You create assets from asset models. With asset models, you can easily create assets of the same type that have standardized definitions. Each asset created from a model inherits the asset model's property and hierarchy definitions. For more information, see Defining asset models in the AWS IoT SiteWise User Guide.

# Required Parameters
- `assetModelName`: A unique, friendly name for the asset model.

# Optional Parameters
- `assetModelDescription`: A description for the asset model.
- `assetModelHierarchies`: The hierarchy definitions of the asset model. Each hierarchy specifies an asset model whose assets can be children of any other assets created from this asset model. For more information, see Asset hierarchies in the AWS IoT SiteWise User Guide. You can specify up to 10 hierarchies per asset model. For more information, see Quotas in the AWS IoT SiteWise User Guide.
- `assetModelProperties`: The property definitions of the asset model. For more information, see Asset properties in the AWS IoT SiteWise User Guide. You can specify up to 200 properties per asset model. For more information, see Quotas in the AWS IoT SiteWise User Guide.
- `clientToken`: A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
- `tags`: A list of key-value pairs that contain metadata for the asset model. For more information, see Tagging your AWS IoT SiteWise resources in the AWS IoT SiteWise User Guide.
"""

create_asset_model(assetModelName; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/asset-models", Dict{String, Any}("assetModelName"=>assetModelName, "clientToken"=>string(uuid4())); aws_config=aws_config)
create_asset_model(assetModelName, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/asset-models", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("assetModelName"=>assetModelName, "clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    CreateDashboard()

Creates a dashboard in an AWS IoT SiteWise Monitor project.

# Required Parameters
- `dashboardDefinition`: The dashboard definition specified in a JSON literal. For detailed information, see Creating dashboards (CLI) in the AWS IoT SiteWise User Guide.
- `dashboardName`: A friendly name for the dashboard.
- `projectId`: The ID of the project in which to create the dashboard.

# Optional Parameters
- `clientToken`: A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
- `dashboardDescription`: A description for the dashboard.
- `tags`: A list of key-value pairs that contain metadata for the dashboard. For more information, see Tagging your AWS IoT SiteWise resources in the AWS IoT SiteWise User Guide.
"""

create_dashboard(dashboardDefinition, dashboardName, projectId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/dashboards", Dict{String, Any}("dashboardDefinition"=>dashboardDefinition, "dashboardName"=>dashboardName, "projectId"=>projectId, "clientToken"=>string(uuid4())); aws_config=aws_config)
create_dashboard(dashboardDefinition, dashboardName, projectId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/dashboards", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("dashboardDefinition"=>dashboardDefinition, "dashboardName"=>dashboardName, "projectId"=>projectId, "clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    CreateGateway()

Creates a gateway, which is a virtual or edge device that delivers industrial data streams from local servers to AWS IoT SiteWise. For more information, see Ingesting data using a gateway in the AWS IoT SiteWise User Guide.

# Required Parameters
- `gatewayName`: A unique, friendly name for the gateway.
- `gatewayPlatform`: The gateway's platform. You can only specify one platform in a gateway.

# Optional Parameters
- `tags`: A list of key-value pairs that contain metadata for the gateway. For more information, see Tagging your AWS IoT SiteWise resources in the AWS IoT SiteWise User Guide.
"""

create_gateway(gatewayName, gatewayPlatform; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/20200301/gateways", Dict{String, Any}("gatewayName"=>gatewayName, "gatewayPlatform"=>gatewayPlatform); aws_config=aws_config)
create_gateway(gatewayName, gatewayPlatform, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/20200301/gateways", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("gatewayName"=>gatewayName, "gatewayPlatform"=>gatewayPlatform), args)); aws_config=aws_config)

"""
    CreatePortal()

Creates a portal, which can contain projects and dashboards. Before you can create a portal, you must enable AWS Single Sign-On. AWS IoT SiteWise Monitor uses AWS SSO to manage user permissions. For more information, see Enabling AWS SSO in the AWS IoT SiteWise User Guide.  Before you can sign in to a new portal, you must add at least one AWS SSO user or group to that portal. For more information, see Adding or removing portal administrators in the AWS IoT SiteWise User Guide. 

# Required Parameters
- `portalContactEmail`: The AWS administrator's contact email address.
- `portalName`: A friendly name for the portal.
- `roleArn`: The ARN of a service role that allows the portal's users to access your AWS IoT SiteWise resources on your behalf. For more information, see Using service roles for AWS IoT SiteWise Monitor in the AWS IoT SiteWise User Guide.

# Optional Parameters
- `clientToken`: A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
- `portalDescription`: A description for the portal.
- `portalLogoImageFile`: A logo image to display in the portal. Upload a square, high-resolution image. The image is displayed on a dark background.
- `tags`: A list of key-value pairs that contain metadata for the portal. For more information, see Tagging your AWS IoT SiteWise resources in the AWS IoT SiteWise User Guide.
"""

create_portal(portalContactEmail, portalName, roleArn; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/portals", Dict{String, Any}("portalContactEmail"=>portalContactEmail, "portalName"=>portalName, "roleArn"=>roleArn, "clientToken"=>string(uuid4())); aws_config=aws_config)
create_portal(portalContactEmail, portalName, roleArn, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/portals", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("portalContactEmail"=>portalContactEmail, "portalName"=>portalName, "roleArn"=>roleArn, "clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    CreateProject()

Creates a project in the specified portal.

# Required Parameters
- `portalId`: The ID of the portal in which to create the project.
- `projectName`: A friendly name for the project.

# Optional Parameters
- `clientToken`: A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
- `projectDescription`: A description for the project.
- `tags`: A list of key-value pairs that contain metadata for the project. For more information, see Tagging your AWS IoT SiteWise resources in the AWS IoT SiteWise User Guide.
"""

create_project(portalId, projectName; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/projects", Dict{String, Any}("portalId"=>portalId, "projectName"=>projectName, "clientToken"=>string(uuid4())); aws_config=aws_config)
create_project(portalId, projectName, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/projects", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("portalId"=>portalId, "projectName"=>projectName, "clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    DeleteAccessPolicy()

Deletes an access policy that grants the specified AWS Single Sign-On identity access to the specified AWS IoT SiteWise Monitor resource. You can use this operation to revoke access to an AWS IoT SiteWise Monitor resource.

# Required Parameters
- `accessPolicyId`: The ID of the access policy to be deleted.

# Optional Parameters
- `clientToken`: A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
"""

delete_access_policy(accessPolicyId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("DELETE", "/access-policies/$(accessPolicyId)", Dict{String, Any}("clientToken"=>string(uuid4())); aws_config=aws_config)
delete_access_policy(accessPolicyId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("DELETE", "/access-policies/$(accessPolicyId)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    DeleteAsset()

Deletes an asset. This action can't be undone. For more information, see Deleting assets and models in the AWS IoT SiteWise User Guide.   You can't delete an asset that's associated to another asset. For more information, see DisassociateAssets. 

# Required Parameters
- `assetId`: The ID of the asset to delete.

# Optional Parameters
- `clientToken`: A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
"""

delete_asset(assetId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("DELETE", "/assets/$(assetId)", Dict{String, Any}("clientToken"=>string(uuid4())); aws_config=aws_config)
delete_asset(assetId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("DELETE", "/assets/$(assetId)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    DeleteAssetModel()

Deletes an asset model. This action can't be undone. You must delete all assets created from an asset model before you can delete the model. Also, you can't delete an asset model if a parent asset model exists that contains a property formula expression that depends on the asset model that you want to delete. For more information, see Deleting assets and models in the AWS IoT SiteWise User Guide.

# Required Parameters
- `assetModelId`: The ID of the asset model to delete.

# Optional Parameters
- `clientToken`: A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
"""

delete_asset_model(assetModelId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("DELETE", "/asset-models/$(assetModelId)", Dict{String, Any}("clientToken"=>string(uuid4())); aws_config=aws_config)
delete_asset_model(assetModelId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("DELETE", "/asset-models/$(assetModelId)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    DeleteDashboard()

Deletes a dashboard from AWS IoT SiteWise Monitor.

# Required Parameters
- `dashboardId`: The ID of the dashboard to delete.

# Optional Parameters
- `clientToken`: A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
"""

delete_dashboard(dashboardId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("DELETE", "/dashboards/$(dashboardId)", Dict{String, Any}("clientToken"=>string(uuid4())); aws_config=aws_config)
delete_dashboard(dashboardId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("DELETE", "/dashboards/$(dashboardId)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    DeleteGateway()

Deletes a gateway from AWS IoT SiteWise. When you delete a gateway, some of the gateway's files remain in your gateway's file system. For more information, see Data retention in the AWS IoT SiteWise User Guide.

# Required Parameters
- `gatewayId`: The ID of the gateway to delete.

"""

delete_gateway(gatewayId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("DELETE", "/20200301/gateways/$(gatewayId)"; aws_config=aws_config)
delete_gateway(gatewayId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("DELETE", "/20200301/gateways/$(gatewayId)", args; aws_config=aws_config)

"""
    DeletePortal()

Deletes a portal from AWS IoT SiteWise Monitor.

# Required Parameters
- `portalId`: The ID of the portal to delete.

# Optional Parameters
- `clientToken`: A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
"""

delete_portal(portalId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("DELETE", "/portals/$(portalId)", Dict{String, Any}("clientToken"=>string(uuid4())); aws_config=aws_config)
delete_portal(portalId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("DELETE", "/portals/$(portalId)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    DeleteProject()

Deletes a project from AWS IoT SiteWise Monitor.

# Required Parameters
- `projectId`: The ID of the project.

# Optional Parameters
- `clientToken`: A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
"""

delete_project(projectId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("DELETE", "/projects/$(projectId)", Dict{String, Any}("clientToken"=>string(uuid4())); aws_config=aws_config)
delete_project(projectId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("DELETE", "/projects/$(projectId)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    DescribeAccessPolicy()

Describes an access policy, which specifies an AWS SSO user or group's access to an AWS IoT SiteWise Monitor portal or project.

# Required Parameters
- `accessPolicyId`: The ID of the access policy.

"""

describe_access_policy(accessPolicyId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/access-policies/$(accessPolicyId)"; aws_config=aws_config)
describe_access_policy(accessPolicyId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/access-policies/$(accessPolicyId)", args; aws_config=aws_config)

"""
    DescribeAsset()

Retrieves information about an asset.

# Required Parameters
- `assetId`: The ID of the asset.

"""

describe_asset(assetId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/assets/$(assetId)"; aws_config=aws_config)
describe_asset(assetId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/assets/$(assetId)", args; aws_config=aws_config)

"""
    DescribeAssetModel()

Retrieves information about an asset model.

# Required Parameters
- `assetModelId`: The ID of the asset model.

"""

describe_asset_model(assetModelId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/asset-models/$(assetModelId)"; aws_config=aws_config)
describe_asset_model(assetModelId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/asset-models/$(assetModelId)", args; aws_config=aws_config)

"""
    DescribeAssetProperty()

Retrieves information about an asset property.  When you call this operation for an attribute property, this response includes the default attribute value that you define in the asset model. If you update the default value in the model, this operation's response includes the new default value.  This operation doesn't return the value of the asset property. To get the value of an asset property, use GetAssetPropertyValue.

# Required Parameters
- `assetId`: The ID of the asset.
- `propertyId`: The ID of the asset property.

"""

describe_asset_property(assetId, propertyId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/assets/$(assetId)/properties/$(propertyId)"; aws_config=aws_config)
describe_asset_property(assetId, propertyId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/assets/$(assetId)/properties/$(propertyId)", args; aws_config=aws_config)

"""
    DescribeDashboard()

Retrieves information about a dashboard.

# Required Parameters
- `dashboardId`: The ID of the dashboard.

"""

describe_dashboard(dashboardId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/dashboards/$(dashboardId)"; aws_config=aws_config)
describe_dashboard(dashboardId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/dashboards/$(dashboardId)", args; aws_config=aws_config)

"""
    DescribeGateway()

Retrieves information about a gateway.

# Required Parameters
- `gatewayId`: The ID of the gateway device.

"""

describe_gateway(gatewayId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/20200301/gateways/$(gatewayId)"; aws_config=aws_config)
describe_gateway(gatewayId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/20200301/gateways/$(gatewayId)", args; aws_config=aws_config)

"""
    DescribeGatewayCapabilityConfiguration()

Retrieves information about a gateway capability configuration. Each gateway capability defines data sources for a gateway. A capability configuration can contain multiple data source configurations. If you define OPC-UA sources for a gateway in the AWS IoT SiteWise console, all of your OPC-UA sources are stored in one capability configuration. To list all capability configurations for a gateway, use DescribeGateway.

# Required Parameters
- `capabilityNamespace`: The namespace of the capability configuration. For example, if you configure OPC-UA sources from the AWS IoT SiteWise console, your OPC-UA capability configuration has the namespace iotsitewise:opcuacollector:version, where version is a number such as 1.
- `gatewayId`: The ID of the gateway that defines the capability configuration.

"""

describe_gateway_capability_configuration(capabilityNamespace, gatewayId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/20200301/gateways/$(gatewayId)/capability/$(capabilityNamespace)"; aws_config=aws_config)
describe_gateway_capability_configuration(capabilityNamespace, gatewayId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/20200301/gateways/$(gatewayId)/capability/$(capabilityNamespace)", args; aws_config=aws_config)

"""
    DescribeLoggingOptions()

Retrieves the current AWS IoT SiteWise logging options.

"""

describe_logging_options(; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/logging"; aws_config=aws_config)
describe_logging_options(args::AbstractDict{String, Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/logging", args; aws_config=aws_config)

"""
    DescribePortal()

Retrieves information about a portal.

# Required Parameters
- `portalId`: The ID of the portal.

"""

describe_portal(portalId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/portals/$(portalId)"; aws_config=aws_config)
describe_portal(portalId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/portals/$(portalId)", args; aws_config=aws_config)

"""
    DescribeProject()

Retrieves information about a project.

# Required Parameters
- `projectId`: The ID of the project.

"""

describe_project(projectId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/projects/$(projectId)"; aws_config=aws_config)
describe_project(projectId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/projects/$(projectId)", args; aws_config=aws_config)

"""
    DisassociateAssets()

Disassociates a child asset from the given parent asset through a hierarchy defined in the parent asset's model.

# Required Parameters
- `assetId`: The ID of the parent asset from which to disassociate the child asset.
- `childAssetId`: The ID of the child asset to disassociate.
- `hierarchyId`: The ID of a hierarchy in the parent asset's model. Hierarchies allow different groupings of assets to be formed that all come from the same asset model. You can use the hierarchy ID to identify the correct asset to disassociate. For more information, see Asset hierarchies in the AWS IoT SiteWise User Guide.

# Optional Parameters
- `clientToken`: A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
"""

disassociate_assets(assetId, childAssetId, hierarchyId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/assets/$(assetId)/disassociate", Dict{String, Any}("childAssetId"=>childAssetId, "hierarchyId"=>hierarchyId, "clientToken"=>string(uuid4())); aws_config=aws_config)
disassociate_assets(assetId, childAssetId, hierarchyId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/assets/$(assetId)/disassociate", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("childAssetId"=>childAssetId, "hierarchyId"=>hierarchyId, "clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    GetAssetPropertyAggregates()

Gets aggregated values for an asset property. For more information, see Querying aggregates in the AWS IoT SiteWise User Guide. To identify an asset property, you must specify one of the following:   The assetId and propertyId of an asset property.   A propertyAlias, which is a data stream alias (for example, /company/windfarm/3/turbine/7/temperature). To define an asset property's alias, see UpdateAssetProperty.  

# Required Parameters
- `aggregateTypes`: The data aggregating function.
- `endDate`: The inclusive end of the range from which to query historical data, expressed in seconds in Unix epoch time.
- `resolution`: The time interval over which to aggregate data.
- `startDate`: The exclusive start of the range from which to query historical data, expressed in seconds in Unix epoch time.

# Optional Parameters
- `assetId`: The ID of the asset.
- `maxResults`: The maximum number of results to be returned per paginated request. Default: 100
- `nextToken`: The token to be used for the next set of paginated results.
- `propertyAlias`: The property alias that identifies the property, such as an OPC-UA server data stream path (for example, /company/windfarm/3/turbine/7/temperature). For more information, see Mapping industrial data streams to asset properties in the AWS IoT SiteWise User Guide.
- `propertyId`: The ID of the asset property.
- `qualities`: The quality by which to filter asset data.
- `timeOrdering`: The chronological sorting order of the requested information. Default: ASCENDING 
"""

get_asset_property_aggregates(aggregateTypes, endDate, resolution, startDate; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/properties/aggregates", Dict{String, Any}("aggregateTypes"=>aggregateTypes, "endDate"=>endDate, "resolution"=>resolution, "startDate"=>startDate); aws_config=aws_config)
get_asset_property_aggregates(aggregateTypes, endDate, resolution, startDate, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/properties/aggregates", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("aggregateTypes"=>aggregateTypes, "endDate"=>endDate, "resolution"=>resolution, "startDate"=>startDate), args)); aws_config=aws_config)

"""
    GetAssetPropertyValue()

Gets an asset property's current value. For more information, see Querying current values in the AWS IoT SiteWise User Guide. To identify an asset property, you must specify one of the following:   The assetId and propertyId of an asset property.   A propertyAlias, which is a data stream alias (for example, /company/windfarm/3/turbine/7/temperature). To define an asset property's alias, see UpdateAssetProperty.  

# Optional Parameters
- `assetId`: The ID of the asset.
- `propertyAlias`: The property alias that identifies the property, such as an OPC-UA server data stream path (for example, /company/windfarm/3/turbine/7/temperature). For more information, see Mapping industrial data streams to asset properties in the AWS IoT SiteWise User Guide.
- `propertyId`: The ID of the asset property.
"""

get_asset_property_value(; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/properties/latest"; aws_config=aws_config)
get_asset_property_value(args::AbstractDict{String, Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/properties/latest", args; aws_config=aws_config)

"""
    GetAssetPropertyValueHistory()

Gets the history of an asset property's values. For more information, see Querying historical values in the AWS IoT SiteWise User Guide. To identify an asset property, you must specify one of the following:   The assetId and propertyId of an asset property.   A propertyAlias, which is a data stream alias (for example, /company/windfarm/3/turbine/7/temperature). To define an asset property's alias, see UpdateAssetProperty.  

# Optional Parameters
- `assetId`: The ID of the asset.
- `endDate`: The inclusive end of the range from which to query historical data, expressed in seconds in Unix epoch time.
- `maxResults`: The maximum number of results to be returned per paginated request. Default: 100
- `nextToken`: The token to be used for the next set of paginated results.
- `propertyAlias`: The property alias that identifies the property, such as an OPC-UA server data stream path (for example, /company/windfarm/3/turbine/7/temperature). For more information, see Mapping industrial data streams to asset properties in the AWS IoT SiteWise User Guide.
- `propertyId`: The ID of the asset property.
- `qualities`: The quality by which to filter asset data.
- `startDate`: The exclusive start of the range from which to query historical data, expressed in seconds in Unix epoch time.
- `timeOrdering`: The chronological sorting order of the requested information. Default: ASCENDING 
"""

get_asset_property_value_history(; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/properties/history"; aws_config=aws_config)
get_asset_property_value_history(args::AbstractDict{String, Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/properties/history", args; aws_config=aws_config)

"""
    ListAccessPolicies()

Retrieves a paginated list of access policies for an AWS SSO identity (a user or group) or an AWS IoT SiteWise Monitor resource (a portal or project).

# Optional Parameters
- `identityId`: The ID of the identity. This parameter is required if you specify identityType.
- `identityType`: The type of identity (user or group). This parameter is required if you specify identityId.
- `maxResults`: The maximum number of results to be returned per paginated request. Default: 50
- `nextToken`: The token to be used for the next set of paginated results.
- `resourceId`: The ID of the resource. This parameter is required if you specify resourceType.
- `resourceType`: The type of resource (portal or project). This parameter is required if you specify resourceId.
"""

list_access_policies(; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/access-policies"; aws_config=aws_config)
list_access_policies(args::AbstractDict{String, Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/access-policies", args; aws_config=aws_config)

"""
    ListAssetModels()

Retrieves a paginated list of summaries of all asset models.

# Optional Parameters
- `maxResults`: The maximum number of results to be returned per paginated request. Default: 50
- `nextToken`: The token to be used for the next set of paginated results.
"""

list_asset_models(; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/asset-models"; aws_config=aws_config)
list_asset_models(args::AbstractDict{String, Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/asset-models", args; aws_config=aws_config)

"""
    ListAssets()

Retrieves a paginated list of asset summaries. You can use this operation to do the following:   List assets based on a specific asset model.   List top-level assets.   You can't use this operation to list all assets. To retrieve summaries for all of your assets, use ListAssetModels to get all of your asset model IDs. Then, use ListAssets to get all assets for each asset model.

# Optional Parameters
- `assetModelId`: The ID of the asset model by which to filter the list of assets. This parameter is required if you choose ALL for filter.
- `filter`: The filter for the requested list of assets. Choose one of the following options:    ALL – The list includes all assets for a given asset model ID. The assetModelId parameter is required if you filter by ALL.    TOP_LEVEL – The list includes only top-level assets in the asset hierarchy tree.   Default: ALL 
- `maxResults`: The maximum number of results to be returned per paginated request. Default: 50
- `nextToken`: The token to be used for the next set of paginated results.
"""

list_assets(; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/assets"; aws_config=aws_config)
list_assets(args::AbstractDict{String, Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/assets", args; aws_config=aws_config)

"""
    ListAssociatedAssets()

Retrieves a paginated list of associated assets. You can use this operation to do the following:   List child assets associated to a parent asset by a hierarchy that you specify.   List an asset's parent asset.  

# Required Parameters
- `assetId`: The ID of the asset to query.

# Optional Parameters
- `hierarchyId`: The ID of the hierarchy by which child assets are associated to the asset. To find a hierarchy ID, use the DescribeAsset or DescribeAssetModel operations. This parameter is required if you choose CHILD for traversalDirection. For more information, see Asset hierarchies in the AWS IoT SiteWise User Guide.
- `maxResults`: The maximum number of results to be returned per paginated request. Default: 50
- `nextToken`: The token to be used for the next set of paginated results.
- `traversalDirection`: The direction to list associated assets. Choose one of the following options:    CHILD – The list includes all child assets associated to the asset. The hierarchyId parameter is required if you choose CHILD.    PARENT – The list includes the asset's parent asset.   Default: CHILD 
"""

list_associated_assets(assetId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/assets/$(assetId)/hierarchies"; aws_config=aws_config)
list_associated_assets(assetId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/assets/$(assetId)/hierarchies", args; aws_config=aws_config)

"""
    ListDashboards()

Retrieves a paginated list of dashboards for an AWS IoT SiteWise Monitor project.

# Required Parameters
- `projectId`: The ID of the project.

# Optional Parameters
- `maxResults`: The maximum number of results to be returned per paginated request. Default: 50
- `nextToken`: The token to be used for the next set of paginated results.
"""

list_dashboards(projectId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/dashboards", Dict{String, Any}("projectId"=>projectId); aws_config=aws_config)
list_dashboards(projectId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/dashboards", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("projectId"=>projectId), args)); aws_config=aws_config)

"""
    ListGateways()

Retrieves a paginated list of gateways.

# Optional Parameters
- `maxResults`: The maximum number of results to be returned per paginated request. Default: 50
- `nextToken`: The token to be used for the next set of paginated results.
"""

list_gateways(; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/20200301/gateways"; aws_config=aws_config)
list_gateways(args::AbstractDict{String, Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/20200301/gateways", args; aws_config=aws_config)

"""
    ListPortals()

Retrieves a paginated list of AWS IoT SiteWise Monitor portals.

# Optional Parameters
- `maxResults`: The maximum number of results to be returned per paginated request. Default: 50
- `nextToken`: The token to be used for the next set of paginated results.
"""

list_portals(; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/portals"; aws_config=aws_config)
list_portals(args::AbstractDict{String, Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/portals", args; aws_config=aws_config)

"""
    ListProjectAssets()

Retrieves a paginated list of assets associated with an AWS IoT SiteWise Monitor project.

# Required Parameters
- `projectId`: The ID of the project.

# Optional Parameters
- `maxResults`: The maximum number of results to be returned per paginated request. Default: 50
- `nextToken`: The token to be used for the next set of paginated results.
"""

list_project_assets(projectId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/projects/$(projectId)/assets"; aws_config=aws_config)
list_project_assets(projectId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/projects/$(projectId)/assets", args; aws_config=aws_config)

"""
    ListProjects()

Retrieves a paginated list of projects for an AWS IoT SiteWise Monitor portal.

# Required Parameters
- `portalId`: The ID of the portal.

# Optional Parameters
- `maxResults`: The maximum number of results to be returned per paginated request. Default: 50
- `nextToken`: The token to be used for the next set of paginated results.
"""

list_projects(portalId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/projects", Dict{String, Any}("portalId"=>portalId); aws_config=aws_config)
list_projects(portalId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/projects", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("portalId"=>portalId), args)); aws_config=aws_config)

"""
    ListTagsForResource()

Retrieves the list of tags for an AWS IoT SiteWise resource.

# Required Parameters
- `resourceArn`: The ARN of the resource.

"""

list_tags_for_resource(resourceArn; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/tags", Dict{String, Any}("resourceArn"=>resourceArn); aws_config=aws_config)
list_tags_for_resource(resourceArn, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("GET", "/tags", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("resourceArn"=>resourceArn), args)); aws_config=aws_config)

"""
    PutLoggingOptions()

Sets logging options for AWS IoT SiteWise.

# Required Parameters
- `loggingOptions`: The logging options to set.

"""

put_logging_options(loggingOptions; aws_config::AWSConfig=global_aws_config()) = iotsitewise("PUT", "/logging", Dict{String, Any}("loggingOptions"=>loggingOptions); aws_config=aws_config)
put_logging_options(loggingOptions, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("PUT", "/logging", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("loggingOptions"=>loggingOptions), args)); aws_config=aws_config)

"""
    TagResource()

Adds tags to an AWS IoT SiteWise resource. If a tag already exists for the resource, this operation updates the tag's value.

# Required Parameters
- `resourceArn`: The ARN of the resource to tag.
- `tags`: A list of key-value pairs that contain metadata for the resource. For more information, see Tagging your AWS IoT SiteWise resources in the AWS IoT SiteWise User Guide.

"""

tag_resource(resourceArn, tags; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/tags", Dict{String, Any}("resourceArn"=>resourceArn, "tags"=>tags); aws_config=aws_config)
tag_resource(resourceArn, tags, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/tags", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("resourceArn"=>resourceArn, "tags"=>tags), args)); aws_config=aws_config)

"""
    UntagResource()

Removes a tag from an AWS IoT SiteWise resource.

# Required Parameters
- `resourceArn`: The ARN of the resource to untag.
- `tagKeys`: A list of keys for tags to remove from the resource.

"""

untag_resource(resourceArn, tagKeys; aws_config::AWSConfig=global_aws_config()) = iotsitewise("DELETE", "/tags", Dict{String, Any}("resourceArn"=>resourceArn, "tagKeys"=>tagKeys); aws_config=aws_config)
untag_resource(resourceArn, tagKeys, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("DELETE", "/tags", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("resourceArn"=>resourceArn, "tagKeys"=>tagKeys), args)); aws_config=aws_config)

"""
    UpdateAccessPolicy()

Updates an existing access policy that specifies an AWS SSO user or group's access to an AWS IoT SiteWise Monitor portal or project resource.

# Required Parameters
- `accessPolicyId`: The ID of the access policy.
- `accessPolicyIdentity`: The identity for this access policy. Choose either a user or a group but not both.
- `accessPolicyPermission`: The permission level for this access policy. Note that a project ADMINISTRATOR is also known as a project owner.
- `accessPolicyResource`: The AWS IoT SiteWise Monitor resource for this access policy. Choose either portal or project but not both.

# Optional Parameters
- `clientToken`: A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
"""

update_access_policy(accessPolicyId, accessPolicyIdentity, accessPolicyPermission, accessPolicyResource; aws_config::AWSConfig=global_aws_config()) = iotsitewise("PUT", "/access-policies/$(accessPolicyId)", Dict{String, Any}("accessPolicyIdentity"=>accessPolicyIdentity, "accessPolicyPermission"=>accessPolicyPermission, "accessPolicyResource"=>accessPolicyResource, "clientToken"=>string(uuid4())); aws_config=aws_config)
update_access_policy(accessPolicyId, accessPolicyIdentity, accessPolicyPermission, accessPolicyResource, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("PUT", "/access-policies/$(accessPolicyId)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("accessPolicyIdentity"=>accessPolicyIdentity, "accessPolicyPermission"=>accessPolicyPermission, "accessPolicyResource"=>accessPolicyResource, "clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    UpdateAsset()

Updates an asset's name. For more information, see Updating assets and models in the AWS IoT SiteWise User Guide.

# Required Parameters
- `assetId`: The ID of the asset to update.
- `assetName`: A unique, friendly name for the asset.

# Optional Parameters
- `clientToken`: A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
"""

update_asset(assetId, assetName; aws_config::AWSConfig=global_aws_config()) = iotsitewise("PUT", "/assets/$(assetId)", Dict{String, Any}("assetName"=>assetName, "clientToken"=>string(uuid4())); aws_config=aws_config)
update_asset(assetId, assetName, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("PUT", "/assets/$(assetId)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("assetName"=>assetName, "clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    UpdateAssetModel()

Updates an asset model and all of the assets that were created from the model. Each asset created from the model inherits the updated asset model's property and hierarchy definitions. For more information, see Updating assets and models in the AWS IoT SiteWise User Guide.  This operation overwrites the existing model with the provided model. To avoid deleting your asset model's properties or hierarchies, you must include their IDs and definitions in the updated asset model payload. For more information, see DescribeAssetModel. If you remove a property from an asset model or update a property's formula expression, AWS IoT SiteWise deletes all previous data for that property. If you remove a hierarchy definition from an asset model, AWS IoT SiteWise disassociates every asset associated with that hierarchy. You can't change the type or data type of an existing property. 

# Required Parameters
- `assetModelId`: The ID of the asset model to update.
- `assetModelName`: A unique, friendly name for the asset model.

# Optional Parameters
- `assetModelDescription`: A description for the asset model.
- `assetModelHierarchies`: The updated hierarchy definitions of the asset model. Each hierarchy specifies an asset model whose assets can be children of any other assets created from this asset model. For more information, see Asset hierarchies in the AWS IoT SiteWise User Guide. You can specify up to 10 hierarchies per asset model. For more information, see Quotas in the AWS IoT SiteWise User Guide.
- `assetModelProperties`: The updated property definitions of the asset model. For more information, see Asset properties in the AWS IoT SiteWise User Guide. You can specify up to 200 properties per asset model. For more information, see Quotas in the AWS IoT SiteWise User Guide.
- `clientToken`: A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
"""

update_asset_model(assetModelId, assetModelName; aws_config::AWSConfig=global_aws_config()) = iotsitewise("PUT", "/asset-models/$(assetModelId)", Dict{String, Any}("assetModelName"=>assetModelName, "clientToken"=>string(uuid4())); aws_config=aws_config)
update_asset_model(assetModelId, assetModelName, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("PUT", "/asset-models/$(assetModelId)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("assetModelName"=>assetModelName, "clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    UpdateAssetProperty()

Updates an asset property's alias and notification state.  This operation overwrites the property's existing alias and notification state. To keep your existing property's alias or notification state, you must include the existing values in the UpdateAssetProperty request. For more information, see DescribeAssetProperty. 

# Required Parameters
- `assetId`: The ID of the asset to be updated.
- `propertyId`: The ID of the asset property to be updated.

# Optional Parameters
- `clientToken`: A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
- `propertyAlias`: The property alias that identifies the property, such as an OPC-UA server data stream path (for example, /company/windfarm/3/turbine/7/temperature). For more information, see Mapping industrial data streams to asset properties in the AWS IoT SiteWise User Guide. If you omit this parameter, the alias is removed from the property.
- `propertyNotificationState`: The MQTT notification state (enabled or disabled) for this asset property. When the notification state is enabled, AWS IoT SiteWise publishes property value updates to a unique MQTT topic. For more information, see Interacting with other services in the AWS IoT SiteWise User Guide. If you omit this parameter, the notification state is set to DISABLED.
"""

update_asset_property(assetId, propertyId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("PUT", "/assets/$(assetId)/properties/$(propertyId)", Dict{String, Any}("clientToken"=>string(uuid4())); aws_config=aws_config)
update_asset_property(assetId, propertyId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("PUT", "/assets/$(assetId)/properties/$(propertyId)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    UpdateDashboard()

Updates an AWS IoT SiteWise Monitor dashboard.

# Required Parameters
- `dashboardDefinition`: The new dashboard definition, as specified in a JSON literal. For detailed information, see Creating dashboards (CLI) in the AWS IoT SiteWise User Guide.
- `dashboardId`: The ID of the dashboard to update.
- `dashboardName`: A new friendly name for the dashboard.

# Optional Parameters
- `clientToken`: A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
- `dashboardDescription`: A new description for the dashboard.
"""

update_dashboard(dashboardDefinition, dashboardId, dashboardName; aws_config::AWSConfig=global_aws_config()) = iotsitewise("PUT", "/dashboards/$(dashboardId)", Dict{String, Any}("dashboardDefinition"=>dashboardDefinition, "dashboardName"=>dashboardName, "clientToken"=>string(uuid4())); aws_config=aws_config)
update_dashboard(dashboardDefinition, dashboardId, dashboardName, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("PUT", "/dashboards/$(dashboardId)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("dashboardDefinition"=>dashboardDefinition, "dashboardName"=>dashboardName, "clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    UpdateGateway()

Updates a gateway's name.

# Required Parameters
- `gatewayId`: The ID of the gateway to update.
- `gatewayName`: A unique, friendly name for the gateway.

"""

update_gateway(gatewayId, gatewayName; aws_config::AWSConfig=global_aws_config()) = iotsitewise("PUT", "/20200301/gateways/$(gatewayId)", Dict{String, Any}("gatewayName"=>gatewayName); aws_config=aws_config)
update_gateway(gatewayId, gatewayName, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("PUT", "/20200301/gateways/$(gatewayId)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("gatewayName"=>gatewayName), args)); aws_config=aws_config)

"""
    UpdateGatewayCapabilityConfiguration()

Updates a gateway capability configuration or defines a new capability configuration. Each gateway capability defines data sources for a gateway. A capability configuration can contain multiple data source configurations. If you define OPC-UA sources for a gateway in the AWS IoT SiteWise console, all of your OPC-UA sources are stored in one capability configuration. To list all capability configurations for a gateway, use DescribeGateway.

# Required Parameters
- `capabilityConfiguration`: The JSON document that defines the configuration for the gateway capability. For more information, see Configuring data sources (CLI) in the AWS IoT SiteWise User Guide.
- `capabilityNamespace`: The namespace of the gateway capability configuration to be updated. For example, if you configure OPC-UA sources from the AWS IoT SiteWise console, your OPC-UA capability configuration has the namespace iotsitewise:opcuacollector:version, where version is a number such as 1.
- `gatewayId`: The ID of the gateway to be updated.

"""

update_gateway_capability_configuration(capabilityConfiguration, capabilityNamespace, gatewayId; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/20200301/gateways/$(gatewayId)/capability", Dict{String, Any}("capabilityConfiguration"=>capabilityConfiguration, "capabilityNamespace"=>capabilityNamespace); aws_config=aws_config)
update_gateway_capability_configuration(capabilityConfiguration, capabilityNamespace, gatewayId, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("POST", "/20200301/gateways/$(gatewayId)/capability", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("capabilityConfiguration"=>capabilityConfiguration, "capabilityNamespace"=>capabilityNamespace), args)); aws_config=aws_config)

"""
    UpdatePortal()

Updates an AWS IoT SiteWise Monitor portal.

# Required Parameters
- `portalContactEmail`: The AWS administrator's contact email address.
- `portalId`: The ID of the portal to update.
- `portalName`: A new friendly name for the portal.
- `roleArn`: The ARN of a service role that allows the portal's users to access your AWS IoT SiteWise resources on your behalf. For more information, see Using service roles for AWS IoT SiteWise Monitor in the AWS IoT SiteWise User Guide.

# Optional Parameters
- `clientToken`: A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
- `portalDescription`: A new description for the portal.
- `portalLogoImage`: 
"""

update_portal(portalContactEmail, portalId, portalName, roleArn; aws_config::AWSConfig=global_aws_config()) = iotsitewise("PUT", "/portals/$(portalId)", Dict{String, Any}("portalContactEmail"=>portalContactEmail, "portalName"=>portalName, "roleArn"=>roleArn, "clientToken"=>string(uuid4())); aws_config=aws_config)
update_portal(portalContactEmail, portalId, portalName, roleArn, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("PUT", "/portals/$(portalId)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("portalContactEmail"=>portalContactEmail, "portalName"=>portalName, "roleArn"=>roleArn, "clientToken"=>string(uuid4())), args)); aws_config=aws_config)

"""
    UpdateProject()

Updates an AWS IoT SiteWise Monitor project.

# Required Parameters
- `projectId`: The ID of the project to update.
- `projectName`: A new friendly name for the project.

# Optional Parameters
- `clientToken`: A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required.
- `projectDescription`: A new description for the project.
"""

update_project(projectId, projectName; aws_config::AWSConfig=global_aws_config()) = iotsitewise("PUT", "/projects/$(projectId)", Dict{String, Any}("projectName"=>projectName, "clientToken"=>string(uuid4())); aws_config=aws_config)
update_project(projectId, projectName, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = iotsitewise("PUT", "/projects/$(projectId)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("projectName"=>projectName, "clientToken"=>string(uuid4())), args)); aws_config=aws_config)
